separator_map = {
    '−': '-',
    '\u2000': r' ',
    '\u2001': r'   ',
    '\u2002': r'  ',
    '\u2003': r'   ',
    '\u2004': r' ',
    '\u2005': r' ',
    '\u2006': r' ',
    '\u2007': r' ',
    '\u2008': r' ',
    '\u2009': r' ',
    '\u200a': r' ',
    '\u200b': r' ',
    '\u202f': r' ',
    '\u205f': r' ',
    '\u3000': r' ',
    '\ufeff': r' ',
    '\u2010': r'-',
    '\u2011': r'-',
    '\u2012': r'--',
    '\u2013': r'--',
    '\u2014': r'---',
    '―': '---',
    '\xa0':  ' ',
}

char_map = {
 '#': '\\#',
 '$': '{\\textdollar}',
 '%': '\\%',
 '&': '\\&',
 '*': '$\\ast$',
 '\\': '{\\textbackslash}',
 '^': '\\^{}',
 '_': '\\_',
 '`': '{\\textasciigrave}',
 '{': '{\\lbrace}',
 '|': '{\\vert}',
 '}': '{\\rbrace}',
 '~': '{\\textasciitilde}',
 '\xa0': ' ',
 '¡': '{\\textexclamdown}',
 '¢': '{\\textcent}',
 '£': '{\\textsterling}',
 '¤': '{\\textcurrency}',
 '¥': '{\\textyen}',
 '¦': '{\\textbrokenbar}',
 '§': '{\\textsection}',
 '¨': '{\\textasciidieresis}',
 '©': '{\\textcopyright}',
 'ª': '{\\textordfeminine}',
 '«': '{\\guillemotleft}',
 '¬': '{\\lnot}',
 '\xad': '\\-',
 '®': '{\\textregistered}',
 '¯': '{\\textasciimacron}',
 '°': '{\\textdegree}',
 '±': '{\\pm}',
 '²': '$^2$',
 '³': '$^3$',
 '´': '{\\textasciiacute}',
 'µ': '\\mathrm{\\mu}',
 '¶': '{\\textparagraph}',
 '·': '{\\cdot}',
 '¸': '\\c{}',
 '¹': '$^1$',
 'º': '{\\textordmasculine}',
 '»': '{\\guillemotright}',
 '¼': '{\\textonequarter}',
 '½': '{\\textonehalf}',
 '¾': '{\\textthreequarters}',
 '¿': '{\\textquestiondown}',
 'À': '\\`{A}',
 'Á': "\\'{A}",
 'Â': '\\^{A}',
 'Ã': '\\~{A}',
 'Ä': '\\"{A}',
 'Å': '{\\AA}',
 'Æ': '{\\AE}',
 'Ç': '\\c{C}',
 'È': '\\`{E}',
 'É': "\\'{E}",
 'Ê': '\\^{E}',
 'Ë': '\\"{E}',
 'Ì': '\\`{I}',
 'Í': "\\'{I}",
 'Î': '\\^{I}',
 'Ï': '\\"{I}',
 'Ð': '{\\DH}',
 'Ñ': '\\~{N}',
 'Ò': '\\`{O}',
 'Ó': "\\'{O}",
 'Ô': '\\^{O}',
 'Õ': '\\~{O}',
 'Ö': '\\"{O}',
 '×': '{\\texttimes}',
 'Ø': '{\\O}',
 'Ù': '\\`{U}',
 'Ú': "\\'{U}",
 'Û': '\\^{U}',
 'Ü': '\\"{U}',
 'Ý': "\\'{Y}",
 'Þ': '{\\TH}',
 'ß': '{\\ss}',
 'à': '\\`{a}',
 'á': "\\'{a}",
 'â': '\\^{a}',
 'ã': '\\~{a}',
 'ä': '\\"{a}',
 'å': '{\\aa}',
 'æ': '{\\ae}',
 'ç': '\\c{c}',
 'è': '\\`{e}',
 'é': "\\'{e}",
 'ê': '\\^{e}',
 'ë': '\\"{e}',
 'ì': '\\`{\\i}',
 'í': "\\'{\\i}",
 'î': '\\^{\\i}',
 'ï': '\\"{\\i}',
 'ð': '{\\dh}',
 'ñ': '\\~{n}',
 'ò': '\\`{o}',
 'ó': "\\'{o}",
 'ô': '\\^{o}',
 'õ': '\\~{o}',
 'ö': '\\"{o}',
 '÷': '{\\div}',
 'ø': '{\\o}',
 'ù': '\\`{u}',
 'ú': "\\'{u}",
 'û': '\\^{u}',
 'ü': '\\"{u}',
 'ý': "\\'{y}",
 'þ': '{\\th}',
 'ÿ': '\\"{y}',
 'Ā': '\\={A}',
 'ā': '\\={a}',
 'Ă': '\\u{A}',
 'ă': '\\u{a}',
 'Ą': '\\k{A}',
 'ą': '\\k{a}',
 'Ć': "\\'{C}",
 'ć': "\\'{c}",
 'Ĉ': '\\^{C}',
 'ĉ': '\\^{c}',
 'Ċ': '\\.{C}',
 'ċ': '\\.{c}',
 'Č': '\\v{C}',
 'č': '\\v{c}',
 'Ď': '\\v{D}',
 'ď': '\\v{d}',
 'Đ': '{\\DJ}',
 'đ': '{\\dj}',
 'Ē': '\\={E}',
 'ē': '\\={e}',
 'Ĕ': '\\u{E}',
 'ĕ': '\\u{e}',
 'Ė': '\\.{E}',
 'ė': '\\.{e}',
 'Ę': '\\k{E}',
 'ę': '\\k{e}',
 'Ě': '\\v{E}',
 'ě': '\\v{e}',
 'Ĝ': '\\^{G}',
 'ĝ': '\\^{g}',
 'Ğ': '\\u{G}',
 'ğ': '\\u{g}',
 'Ġ': '\\.{G}',
 'ġ': '\\.{g}',
 'Ģ': '\\c{G}',
 'ģ': '\\c{g}',
 'Ĥ': '\\^{H}',
 'ĥ': '\\^{h}',
 'Ħ': '{\\fontencoding{LELA}\\selectfont\\char40}',
 'ħ': '{\\Elzxh}',
 'Ĩ': '\\~{I}',
 'ĩ': '\\~{\\i}',
 'Ī': '\\={I}',
 'ī': '\\={\\i}',
 'Ĭ': '\\u{I}',
 'ĭ': '\\u{\\i}',
 'Į': '\\k{I}',
 'į': '\\k{i}',
 'İ': '\\.{I}',
 'ı': '{\\i}',
 'Ĳ': 'IJ',
 'ĳ': 'ij',
 'Ĵ': '\\^{J}',
 'ĵ': '\\^{\\j}',
 'Ķ': '\\c{K}',
 'ķ': '\\c{k}',
 'ĸ': '{\\fontencoding{LELA}\\selectfont\\char91}',
 'Ĺ': "\\'{L}",
 'ĺ': "\\'{l}",
 'Ļ': '\\c{L}',
 'ļ': '\\c{l}',
 'Ľ': '\\v{L}',
 'ľ': '\\v{l}',
 'Ŀ': '{\\fontencoding{LELA}\\selectfont\\char201}',
 'ŀ': '{\\fontencoding{LELA}\\selectfont\\char202}',
 'Ł': '{\\L}',
 'ł': '{\\l}',
 'Ń': "\\'{N}",
 'ń': "\\'{n}",
 'Ņ': '\\c{N}',
 'ņ': '\\c{n}',
 'Ň': '\\v{N}',
 'ň': '\\v{n}',
 'ŉ': "'n",
 'Ŋ': '{\\NG}',
 'ŋ': '{\\ng}',
 'Ō': '\\={O}',
 'ō': '\\={o}',
 'Ŏ': '\\u{O}',
 'ŏ': '\\u{o}',
 'Ő': '\\H{O}',
 'ő': '\\H{o}',
 'Œ': '{\\OE}',
 'œ': '{\\oe}',
 'Ŕ': "\\'{R}",
 'ŕ': "\\'{r}",
 'Ŗ': '\\c{R}',
 'ŗ': '\\c{r}',
 'Ř': '\\v{R}',
 'ř': '\\v{r}',
 'Ś': "\\'{S}",
 'ś': "\\'{s}",
 'Ŝ': '\\^{S}',
 'ŝ': '\\^{s}',
 'Ş': '\\c{S}',
 'ş': '\\c{s}',
 'Š': '\\v{S}',
 'š': '\\v{s}',
 'Ţ': '\\c{T}',
 'ţ': '\\c{t}',
 'Ť': '\\v{T}',
 'ť': '\\v{t}',
 'Ŧ': '{\\fontencoding{LELA}\\selectfont\\char47}',
 'ŧ': '{\\fontencoding{LELA}\\selectfont\\char63}',
 'Ũ': '\\~{U}',
 'ũ': '\\~{u}',
 'Ū': '\\={U}',
 'ū': '\\={u}',
 'Ŭ': '\\u{U}',
 'ŭ': '\\u{u}',
 'Ů': '\\r{U}',
 'ů': '\\r{u}',
 'Ű': '\\H{U}',
 'ű': '\\H{u}',
 'Ų': '\\k{U}',
 'ų': '\\k{u}',
 'Ŵ': '\\^{W}',
 'ŵ': '\\^{w}',
 'Ŷ': '\\^{Y}',
 'ŷ': '\\^{y}',
 'Ÿ': '\\"{Y}',
 'Ź': "\\'{Z}",
 'ź': "\\'{z}",
 'Ż': '\\.{Z}',
 'ż': '\\.{z}',
 'Ž': '\\v{Z}',
 'ž': '\\v{z}',
 'ƒ': 'f',
 'ƕ': '{\\texthvlig}',
 'ƞ': '{\\textnrleg}',
 'ƪ': '{\\eth}',
 'ƺ': '{\\fontencoding{LELA}\\selectfont\\char195}',
 'ǂ': '{\\textdoublepipe}',
 'ǵ': "\\'{g}",
 'ɐ': '{\\Elztrna}',
 'ɒ': '{\\Elztrnsa}',
 'ɔ': '{\\Elzopeno}',
 'ɖ': '{\\Elzrtld}',
 'ɘ': '{\\fontencoding{LEIP}\\selectfont\\char61}',
 'ə': '{\\Elzschwa}',
 'ɛ': '{\\varepsilon}',
 'ɡ': 'g',
 'ɣ': '{\\Elzpgamma}',
 'ɤ': '{\\Elzpbgam}',
 'ɥ': '{\\Elztrnh}',
 'ɬ': '{\\Elzbtdl}',
 'ɭ': '{\\Elzrtll}',
 'ɯ': '{\\Elztrnm}',
 'ɰ': '{\\Elztrnmlr}',
 'ɱ': '{\\Elzltlmr}',
 'ɲ': '{\\Elzltln}',
 'ɳ': '{\\Elzrtln}',
 'ɷ': '{\\Elzclomeg}',
 'ɸ': '{\\textphi}',
 'ɹ': '{\\Elztrnr}',
 'ɺ': '{\\Elztrnrl}',
 'ɻ': '{\\Elzrttrnr}',
 'ɼ': '{\\Elzrl}',
 'ɽ': '{\\Elzrtlr}',
 'ɾ': '{\\Elzfhr}',
 'ɿ': '{\\fontencoding{LEIP}\\selectfont\\char202}',
 'ʂ': '{\\Elzrtls}',
 'ʃ': '{\\Elzesh}',
 'ʇ': '{\\Elztrnt}',
 'ʈ': '{\\Elzrtlt}',
 'ʊ': '{\\Elzpupsil}',
 'ʋ': '{\\Elzpscrv}',
 'ʌ': '{\\Elzinvv}',
 'ʍ': '{\\Elzinvw}',
 'ʎ': '{\\Elztrny}',
 'ʐ': '{\\Elzrtlz}',
 'ʒ': '{\\Elzyogh}',
 'ʔ': '{\\Elzglst}',
 'ʕ': '{\\Elzreglst}',
 'ʖ': '{\\Elzinglst}',
 'ʞ': '{\\textturnk}',
 'ʤ': '{\\Elzdyogh}',
 'ʧ': '{\\Elztesh}',
 'ʼ': "'",
 'ˇ': '{\\textasciicaron}',
 'ˈ': '{\\Elzverts}',
 'ˌ': '{\\Elzverti}',
 'ː': '{\\Elzlmrk}',
 'ˑ': '{\\Elzhlmrk}',
 '˒': '{\\Elzsbrhr}',
 '˓': '{\\Elzsblhr}',
 '˔': '{\\Elzrais}',
 '˕': '{\\Elzlow}',
 '˘': '{\\textasciibreve}',
 '˙': '{\\textperiodcentered}',
 '˚': '\\r{}',
 '˛': '\\k{}',
 '˜': '{\\texttildelow}',
 '˝': '\\H{}',
 '˥': '\\tone{55}',
 '˦': '\\tone{44}',
 '˧': '\\tone{33}',
 '˨': '\\tone{22}',
 '˩': '\\tone{11}',
 '̀': '\\`',
 '́': "\\'",
 '̂': '\\^',
 '̃': '\\~',
 '̄': '\\=',
 '̆': '{\\u}',
 '̇': '\\.',
 '̈': '\\"',
 '̊': '{\\r}',
 '̋': '{\\H}',
 '̌': '{\\v}',
 '̏': '{\\cyrchar\\C}',
 '̑': '{\\fontencoding{LECO}\\selectfont\\char177}',
 '̘': '{\\fontencoding{LECO}\\selectfont\\char184}',
 '̙': '{\\fontencoding{LECO}\\selectfont\\char185}',
 '̡': '{\\Elzpalh}',
 '̢': '{\\Elzrh}',
 '̧': '{\\c}',
 '̨': '{\\k}',
 '̪': '{\\Elzsbbrg}',
 '̫': '{\\fontencoding{LECO}\\selectfont\\char203}',
 '̯': '{\\fontencoding{LECO}\\selectfont\\char207}',
 '̵': '{\\Elzxl}',
 '̶': '{\\Elzbar}',
 '̷': '{\\fontencoding{LECO}\\selectfont\\char215}',
 '̸': '{\\fontencoding{LECO}\\selectfont\\char216}',
 '̺': '{\\fontencoding{LECO}\\selectfont\\char218}',
 '̻': '{\\fontencoding{LECO}\\selectfont\\char219}',
 '̼': '{\\fontencoding{LECO}\\selectfont\\char220}',
 '̽': '{\\fontencoding{LECO}\\selectfont\\char221}',
 '͡': '{\\fontencoding{LECO}\\selectfont\\char225}',
 'Ά': "\\'{A}",
 'Έ': "\\'{E}",
 'Ή': "\\'{H}",
 'Ί': "\\'{}{I}",
 'Ό': "{\\'{}O}",
 'Ύ': "\\mathrm{'Y}",
 'Ώ': "\\mathrm{'\\Omega}",
 'ΐ': '\\acute{\\ddot{\\iota}}',
 'Α': '{\\Alpha}',
 'Β': '{\\Beta}',
 'Γ': '{\\Gamma}',
 'Δ': '{\\Delta}',
 'Ε': '{\\Epsilon}',
 'Ζ': '{\\Zeta}',
 'Η': '{\\Eta}',
 'Θ': '{\\Theta}',
 'Ι': '{\\Iota}',
 'Κ': '{\\Kappa}',
 'Λ': '{\\Lambda}',
 'Μ': 'M',
 'Ν': 'N',
 'Ξ': '{\\Xi}',
 'Ο': 'O',
 'Π': '{\\Pi}',
 'Ρ': '{\\Rho}',
 'Σ': '{\\Sigma}',
 'Τ': '{\\Tau}',
 'Υ': '{\\Upsilon}',
 'Φ': '{\\Phi}',
 'Χ': '{\\Chi}',
 'Ψ': '{\\Psi}',
 'Ω': '{\\Omega}',
 'Ϊ': '\\mathrm{\\ddot{I}}',
 'Ϋ': '\\mathrm{\\ddot{Y}}',
 'ά': "\\'{$\\alpha$}",
 'έ': '\\acute{\\epsilon}',
 'ή': '\\acute{\\eta}',
 'ί': '\\acute{\\iota}',
 'ΰ': '\\acute{\\ddot{\\upsilon}}',
 'α': '{\\alpha}',
 'β': '{\\beta}',
 'γ': '{\\gamma}',
 'δ': '{\\delta}',
 'ε': '{\\epsilon}',
 'ζ': '{\\zeta}',
 'η': '{\\eta}',
 'θ': '{\\texttheta}',
 'ι': '{\\iota}',
 'κ': '{\\kappa}',
 'λ': '{\\lambda}',
 'μ': '{\\mu}',
 'ν': '{\\nu}',
 'ξ': '{\\xi}',
 'ο': 'o',
 'π': '{\\pi}',
 'ρ': '{\\rho}',
 'ς': '{\\varsigma}',
 'σ': '{\\sigma}',
 'τ': '{\\tau}',
 'υ': '{\\upsilon}',
 'φ': '{\\varphi}',
 'χ': '{\\chi}',
 'ψ': '{\\psi}',
 'ω': '{\\omega}',
 'ϊ': '\\ddot{\\iota}',
 'ϋ': '\\ddot{\\upsilon}',
 'ό': "\\'{o}",
 'ύ': '\\acute{\\upsilon}',
 'ώ': '\\acute{\\omega}',
 'ϐ': '\\Pisymbol{ppi022}{87}',
 'ϑ': '{\\textvartheta}',
 'ϒ': '{\\Upsilon}',
 'ϕ': '{\\phi}',
 'ϖ': '{\\varpi}',
 'Ϛ': '{\\Stigma}',
 'Ϝ': '{\\Digamma}',
 'ϝ': '{\\digamma}',
 'Ϟ': '{\\Koppa}',
 'Ϡ': '{\\Sampi}',
 'ϰ': '{\\varkappa}',
 'ϱ': '{\\varrho}',
 'ϴ': '{\\textTheta}',
 '϶': '{\\backepsilon}',
 'Ё': '{\\cyrchar\\CYRYO}',
 'Ђ': '{\\cyrchar\\CYRDJE}',
 'Ѓ': "\\cyrchar{\\'\\CYRG}",
 'Є': '{\\cyrchar\\CYRIE}',
 'Ѕ': '{\\cyrchar\\CYRDZE}',
 'І': '{\\cyrchar\\CYRII}',
 'Ї': '{\\cyrchar\\CYRYI}',
 'Ј': '{\\cyrchar\\CYRJE}',
 'Љ': '{\\cyrchar\\CYRLJE}',
 'Њ': '{\\cyrchar\\CYRNJE}',
 'Ћ': '{\\cyrchar\\CYRTSHE}',
 'Ќ': "\\cyrchar{\\'\\CYRK}",
 'Ў': '{\\cyrchar\\CYRUSHRT}',
 'Џ': '{\\cyrchar\\CYRDZHE}',
 'А': '{\\cyrchar\\CYRA}',
 'Б': '{\\cyrchar\\CYRB}',
 'В': '{\\cyrchar\\CYRV}',
 'Г': '{\\cyrchar\\CYRG}',
 'Д': '{\\cyrchar\\CYRD}',
 'Е': '{\\cyrchar\\CYRE}',
 'Ж': '{\\cyrchar\\CYRZH}',
 'З': '{\\cyrchar\\CYRZ}',
 'И': '{\\cyrchar\\CYRI}',
 'Й': '{\\cyrchar\\CYRISHRT}',
 'К': '{\\cyrchar\\CYRK}',
 'Л': '{\\cyrchar\\CYRL}',
 'М': '{\\cyrchar\\CYRM}',
 'Н': '{\\cyrchar\\CYRN}',
 'О': '{\\cyrchar\\CYRO}',
 'П': '{\\cyrchar\\CYRP}',
 'Р': '{\\cyrchar\\CYRR}',
 'С': '{\\cyrchar\\CYRS}',
 'Т': '{\\cyrchar\\CYRT}',
 'У': '{\\cyrchar\\CYRU}',
 'Ф': '{\\cyrchar\\CYRF}',
 'Х': '{\\cyrchar\\CYRH}',
 'Ц': '{\\cyrchar\\CYRC}',
 'Ч': '{\\cyrchar\\CYRCH}',
 'Ш': '{\\cyrchar\\CYRSH}',
 'Щ': '{\\cyrchar\\CYRSHCH}',
 'Ъ': '{\\cyrchar\\CYRHRDSN}',
 'Ы': '{\\cyrchar\\CYRERY}',
 'Ь': '{\\cyrchar\\CYRSFTSN}',
 'Э': '{\\cyrchar\\CYREREV}',
 'Ю': '{\\cyrchar\\CYRYU}',
 'Я': '{\\cyrchar\\CYRYA}',
 'а': '{\\cyrchar\\cyra}',
 'б': '{\\cyrchar\\cyrb}',
 'в': '{\\cyrchar\\cyrv}',
 'г': '{\\cyrchar\\cyrg}',
 'д': '{\\cyrchar\\cyrd}',
 'е': '{\\cyrchar\\cyre}',
 'ж': '{\\cyrchar\\cyrzh}',
 'з': '{\\cyrchar\\cyrz}',
 'и': '{\\cyrchar\\cyri}',
 'й': '{\\cyrchar\\cyrishrt}',
 'к': '{\\cyrchar\\cyrk}',
 'л': '{\\cyrchar\\cyrl}',
 'м': '{\\cyrchar\\cyrm}',
 'н': '{\\cyrchar\\cyrn}',
 'о': '{\\cyrchar\\cyro}',
 'п': '{\\cyrchar\\cyrp}',
 'р': '{\\cyrchar\\cyrr}',
 'с': '{\\cyrchar\\cyrs}',
 'т': '{\\cyrchar\\cyrt}',
 'у': '{\\cyrchar\\cyru}',
 'ф': '{\\cyrchar\\cyrf}',
 'х': '{\\cyrchar\\cyrh}',
 'ц': '{\\cyrchar\\cyrc}',
 'ч': '{\\cyrchar\\cyrch}',
 'ш': '{\\cyrchar\\cyrsh}',
 'щ': '{\\cyrchar\\cyrshch}',
 'ъ': '{\\cyrchar\\cyrhrdsn}',
 'ы': '{\\cyrchar\\cyrery}',
 'ь': '{\\cyrchar\\cyrsftsn}',
 'э': '{\\cyrchar\\cyrerev}',
 'ю': '{\\cyrchar\\cyryu}',
 'я': '{\\cyrchar\\cyrya}',
 'ё': '{\\cyrchar\\cyryo}',
 'ђ': '{\\cyrchar\\cyrdje}',
 'ѓ': "\\cyrchar{\\'\\cyrg}",
 'є': '{\\cyrchar\\cyrie}',
 'ѕ': '{\\cyrchar\\cyrdze}',
 'і': '{\\cyrchar\\cyrii}',
 'ї': '{\\cyrchar\\cyryi}',
 'ј': '{\\cyrchar\\cyrje}',
 'љ': '{\\cyrchar\\cyrlje}',
 'њ': '{\\cyrchar\\cyrnje}',
 'ћ': '{\\cyrchar\\cyrtshe}',
 'ќ': "\\cyrchar{\\'\\cyrk}",
 'ў': '{\\cyrchar\\cyrushrt}',
 'џ': '{\\cyrchar\\cyrdzhe}',
 'Ѡ': '{\\cyrchar\\CYROMEGA}',
 'ѡ': '{\\cyrchar\\cyromega}',
 'Ѣ': '{\\cyrchar\\CYRYAT}',
 'Ѥ': '{\\cyrchar\\CYRIOTE}',
 'ѥ': '{\\cyrchar\\cyriote}',
 'Ѧ': '{\\cyrchar\\CYRLYUS}',
 'ѧ': '{\\cyrchar\\cyrlyus}',
 'Ѩ': '{\\cyrchar\\CYRIOTLYUS}',
 'ѩ': '{\\cyrchar\\cyriotlyus}',
 'Ѫ': '{\\cyrchar\\CYRBYUS}',
 'Ѭ': '{\\cyrchar\\CYRIOTBYUS}',
 'ѭ': '{\\cyrchar\\cyriotbyus}',
 'Ѯ': '{\\cyrchar\\CYRKSI}',
 'ѯ': '{\\cyrchar\\cyrksi}',
 'Ѱ': '{\\cyrchar\\CYRPSI}',
 'ѱ': '{\\cyrchar\\cyrpsi}',
 'Ѳ': '{\\cyrchar\\CYRFITA}',
 'Ѵ': '{\\cyrchar\\CYRIZH}',
 'Ѹ': '{\\cyrchar\\CYRUK}',
 'ѹ': '{\\cyrchar\\cyruk}',
 'Ѻ': '{\\cyrchar\\CYROMEGARND}',
 'ѻ': '{\\cyrchar\\cyromegarnd}',
 'Ѽ': '{\\cyrchar\\CYROMEGATITLO}',
 'ѽ': '{\\cyrchar\\cyromegatitlo}',
 'Ѿ': '{\\cyrchar\\CYROT}',
 'ѿ': '{\\cyrchar\\cyrot}',
 'Ҁ': '{\\cyrchar\\CYRKOPPA}',
 'ҁ': '{\\cyrchar\\cyrkoppa}',
 '҂': '{\\cyrchar\\cyrthousands}',
 '҈': '{\\cyrchar\\cyrhundredthousands}',
 '҉': '{\\cyrchar\\cyrmillions}',
 'Ҍ': '{\\cyrchar\\CYRSEMISFTSN}',
 'ҍ': '{\\cyrchar\\cyrsemisftsn}',
 'Ҏ': '{\\cyrchar\\CYRRTICK}',
 'ҏ': '{\\cyrchar\\cyrrtick}',
 'Ґ': '{\\cyrchar\\CYRGUP}',
 'ґ': '{\\cyrchar\\cyrgup}',
 'Ғ': '{\\cyrchar\\CYRGHCRS}',
 'ғ': '{\\cyrchar\\cyrghcrs}',
 'Ҕ': '{\\cyrchar\\CYRGHK}',
 'ҕ': '{\\cyrchar\\cyrghk}',
 'Җ': '{\\cyrchar\\CYRZHDSC}',
 'җ': '{\\cyrchar\\cyrzhdsc}',
 'Ҙ': '{\\cyrchar\\CYRZDSC}',
 'ҙ': '{\\cyrchar\\cyrzdsc}',
 'Қ': '{\\cyrchar\\CYRKDSC}',
 'қ': '{\\cyrchar\\cyrkdsc}',
 'Ҝ': '{\\cyrchar\\CYRKVCRS}',
 'ҝ': '{\\cyrchar\\cyrkvcrs}',
 'Ҟ': '{\\cyrchar\\CYRKHCRS}',
 'ҟ': '{\\cyrchar\\cyrkhcrs}',
 'Ҡ': '{\\cyrchar\\CYRKBEAK}',
 'ҡ': '{\\cyrchar\\cyrkbeak}',
 'Ң': '{\\cyrchar\\CYRNDSC}',
 'ң': '{\\cyrchar\\cyrndsc}',
 'Ҥ': '{\\cyrchar\\CYRNG}',
 'ҥ': '{\\cyrchar\\cyrng}',
 'Ҧ': '{\\cyrchar\\CYRPHK}',
 'ҧ': '{\\cyrchar\\cyrphk}',
 'Ҩ': '{\\cyrchar\\CYRABHHA}',
 'ҩ': '{\\cyrchar\\cyrabhha}',
 'Ҫ': '{\\cyrchar\\CYRSDSC}',
 'ҫ': '{\\cyrchar\\cyrsdsc}',
 'Ҭ': '{\\cyrchar\\CYRTDSC}',
 'ҭ': '{\\cyrchar\\cyrtdsc}',
 'Ү': '{\\cyrchar\\CYRY}',
 'ү': '{\\cyrchar\\cyry}',
 'Ұ': '{\\cyrchar\\CYRYHCRS}',
 'ұ': '{\\cyrchar\\cyryhcrs}',
 'Ҳ': '{\\cyrchar\\CYRHDSC}',
 'ҳ': '{\\cyrchar\\cyrhdsc}',
 'Ҵ': '{\\cyrchar\\CYRTETSE}',
 'ҵ': '{\\cyrchar\\cyrtetse}',
 'Ҷ': '{\\cyrchar\\CYRCHRDSC}',
 'ҷ': '{\\cyrchar\\cyrchrdsc}',
 'Ҹ': '{\\cyrchar\\CYRCHVCRS}',
 'ҹ': '{\\cyrchar\\cyrchvcrs}',
 'Һ': '{\\cyrchar\\CYRSHHA}',
 'һ': '{\\cyrchar\\cyrshha}',
 'Ҽ': '{\\cyrchar\\CYRABHCH}',
 'ҽ': '{\\cyrchar\\cyrabhch}',
 'Ҿ': '{\\cyrchar\\CYRABHCHDSC}',
 'ҿ': '{\\cyrchar\\cyrabhchdsc}',
 'Ӏ': '{\\cyrchar\\CYRpalochka}',
 'Ӄ': '{\\cyrchar\\CYRKHK}',
 'ӄ': '{\\cyrchar\\cyrkhk}',
 'Ӈ': '{\\cyrchar\\CYRNHK}',
 'ӈ': '{\\cyrchar\\cyrnhk}',
 'Ӌ': '{\\cyrchar\\CYRCHLDSC}',
 'ӌ': '{\\cyrchar\\cyrchldsc}',
 'Ӕ': '{\\cyrchar\\CYRAE}',
 'ӕ': '{\\cyrchar\\cyrae}',
 'Ә': '{\\cyrchar\\CYRSCHWA}',
 'ә': '{\\cyrchar\\cyrschwa}',
 'Ӡ': '{\\cyrchar\\CYRABHDZE}',
 'ӡ': '{\\cyrchar\\cyrabhdze}',
 'Ө': '{\\cyrchar\\CYROTLD}',
 'ө': '{\\cyrchar\\cyrotld}',
 '‖': '{\\Vert}',
 '‘': '`',
 '’': "'",
 '‚': ',',
 '‛': '{\\Elzreapos}',
 '“': '{\\textquotedblleft}',
 '”': '{\\textquotedblright}',
 '„': ',,',
 '†': '{\\textdagger}',
 '‡': '{\\textdaggerdbl}',
 '•': '{\\textbullet}',
 '․': '.',
 '‥': '..',
 '…': '{\\ldots}',
 '‰': '{\\textperthousand}',
 '‱': '{\\textpertenthousand}',
 '′': "$'$",
 '″': "$''$",
 '‴': "$'''$",
 '‵': '{\\backprime}',
 '‹': '{\\guilsinglleft}',
 '›': '{\\guilsinglright}',
 '⁗': "''''",
 '\u205f': '{\\mkern4mu}',
 '\u2060': '{\\nolinebreak}',
 '₧': '\\ensuremath{\\Elzpes}',
 '€': '\\mbox{\\texteuro}',
 '⃛': '{\\dddot}',
 '⃜': '{\\ddddot}',
 'ℂ': '\\mathbb{C}',
 'ℊ': '\\mathscr{g}',
 'ℋ': '\\mathscr{H}',
 'ℌ': '\\mathfrak{H}',
 'ℍ': '\\mathbb{H}',
 'ℏ': '{\\hslash}',
 'ℐ': '\\mathscr{I}',
 'ℑ': '\\mathfrak{I}',
 'ℒ': '\\mathscr{L}',
 'ℓ': '\\mathscr{l}',
 'ℕ': '\\mathbb{N}',
 '№': '{\\cyrchar\\textnumero}',
 '℘': '{\\wp}',
 'ℙ': '\\mathbb{P}',
 'ℚ': '\\mathbb{Q}',
 'ℛ': '\\mathscr{R}',
 'ℜ': '\\mathfrak{R}',
 'ℝ': '\\mathbb{R}',
 '℞': '{\\Elzxrat}',
 '™': '{\\texttrademark}',
 'ℤ': '\\mathbb{Z}',
 'Ω': '{\\Omega}',
 '℧': '{\\mho}',
 'ℨ': '\\mathfrak{Z}',
 '℩': '\\ElsevierGlyph{2129}',
 'Å': '{\\AA}',
 'ℬ': '\\mathscr{B}',
 'ℭ': '\\mathfrak{C}',
 'ℯ': '\\mathscr{e}',
 'ℰ': '\\mathscr{E}',
 'ℱ': '\\mathscr{F}',
 'ℳ': '\\mathscr{M}',
 'ℴ': '\\mathscr{o}',
 'ℵ': '{\\aleph}',
 'ℶ': '{\\beth}',
 'ℷ': '{\\gimel}',
 'ℸ': '{\\daleth}',
 '⅓': '\\textfrac{1}{3}',
 '⅔': '\\textfrac{2}{3}',
 '⅕': '\\textfrac{1}{5}',
 '⅖': '\\textfrac{2}{5}',
 '⅗': '\\textfrac{3}{5}',
 '⅘': '\\textfrac{4}{5}',
 '⅙': '\\textfrac{1}{6}',
 '⅚': '\\textfrac{5}{6}',
 '⅛': '\\textfrac{1}{8}',
 '⅜': '\\textfrac{3}{8}',
 '⅝': '\\textfrac{5}{8}',
 '⅞': '\\textfrac{7}{8}',
 '←': '{\\leftarrow}',
 '↑': '{\\uparrow}',
 '→': '{\\rightarrow}',
 '↓': '{\\downarrow}',
 '↔': '{\\leftrightarrow}',
 '↕': '{\\updownarrow}',
 '↖': '{\\nwarrow}',
 '↗': '{\\nearrow}',
 '↘': '{\\searrow}',
 '↙': '{\\swarrow}',
 '↚': '{\\nleftarrow}',
 '↛': '{\\nrightarrow}',
 '↜': '{\\arrowwaveright}',
 '↝': '{\\arrowwaveright}',
 '↞': '{\\twoheadleftarrow}',
 '↠': '{\\twoheadrightarrow}',
 '↢': '{\\leftarrowtail}',
 '↣': '{\\rightarrowtail}',
 '↦': '{\\mapsto}',
 '↩': '{\\hookleftarrow}',
 '↪': '{\\hookrightarrow}',
 '↫': '{\\looparrowleft}',
 '↬': '{\\looparrowright}',
 '↭': '{\\leftrightsquigarrow}',
 '↮': '{\\nleftrightarrow}',
 '↰': '{\\Lsh}',
 '↱': '{\\Rsh}',
 '↳': '\\ElsevierGlyph{21B3}',
 '↶': '{\\curvearrowleft}',
 '↷': '{\\curvearrowright}',
 '↺': '{\\circlearrowleft}',
 '↻': '{\\circlearrowright}',
 '↼': '{\\leftharpoonup}',
 '↽': '{\\leftharpoondown}',
 '↾': '{\\upharpoonright}',
 '↿': '{\\upharpoonleft}',
 '⇀': '{\\rightharpoonup}',
 '⇁': '{\\rightharpoondown}',
 '⇂': '{\\downharpoonright}',
 '⇃': '{\\downharpoonleft}',
 '⇄': '{\\rightleftarrows}',
 '⇅': '{\\dblarrowupdown}',
 '⇆': '{\\leftrightarrows}',
 '⇇': '{\\leftleftarrows}',
 '⇈': '{\\upuparrows}',
 '⇉': '{\\rightrightarrows}',
 '⇊': '{\\downdownarrows}',
 '⇋': '{\\leftrightharpoons}',
 '⇌': '{\\rightleftharpoons}',
 '⇍': '{\\nLeftarrow}',
 '⇎': '{\\nLeftrightarrow}',
 '⇏': '{\\nRightarrow}',
 '⇐': '{\\Leftarrow}',
 '⇑': '{\\Uparrow}',
 '⇒': '{\\Rightarrow}',
 '⇓': '{\\Downarrow}',
 '⇔': '{\\Leftrightarrow}',
 '⇕': '{\\Updownarrow}',
 '⇚': '{\\Lleftarrow}',
 '⇛': '{\\Rrightarrow}',
 '⇝': '{\\rightsquigarrow}',
 '⇵': '{\\DownArrowUpArrow}',
 '∀': '{\\forall}',
 '∁': '{\\complement}',
 '∂': '{\\partial}',
 '∃': '{\\exists}',
 '∄': '{\\nexists}',
 '∅': '{\\varnothing}',
 '∇': '{\\nabla}',
 '∈': '{\\in}',
 '∉': '{\\not\\in}',
 '∋': '{\\ni}',
 '∌': '{\\not\\ni}',
 '∏': '{\\prod}',
 '∐': '{\\coprod}',
 '∑': '{\\sum}',
 '−': '-',
 '∓': '{\\mp}',
 '∔': '{\\dotplus}',
 '∖': '{\\setminus}',
 '∗': '$_\\ast$',
 '∘': '{\\circ}',
 '∙': '{\\bullet}',
 '√': '{\\surd}',
 '∝': '{\\propto}',
 '∞': '{\\infty}',
 '∟': '{\\rightangle}',
 '∠': '{\\angle}',
 '∡': '{\\measuredangle}',
 '∢': '{\\sphericalangle}',
 '∣': '{\\mid}',
 '∤': '{\\nmid}',
 '∥': '{\\parallel}',
 '∦': '{\\nparallel}',
 '∧': '{\\wedge}',
 '∨': '{\\vee}',
 '∩': '{\\cap}',
 '∪': '{\\cup}',
 '∫': '{\\int}',
 '∬': '{\\int\\!\\int}',
 '∭': '{\\int\\!\\int\\!\\int}',
 '∮': '{\\oint}',
 '∯': '{\\surfintegral}',
 '∰': '{\\volintegral}',
 '∱': '{\\clwintegral}',
 '∲': '\\ElsevierGlyph{2232}',
 '∳': '\\ElsevierGlyph{2233}',
 '∴': '{\\therefore}',
 '∵': '{\\because}',
 '∷': '{\\Colon}',
 '∸': '\\ElsevierGlyph{2238}',
 '∺': '\\mathbin{{:}\\!\\!{-}\\!\\!{:}}',
 '∻': '{\\homothetic}',
 '∼': '{\\sim}',
 '∽': '{\\backsim}',
 '∾': '{\\lazysinv}',
 '≀': '{\\wr}',
 '≁': '{\\not\\sim}',
 '≂': '\\ElsevierGlyph{2242}',
 '≂̸': '{\\NotEqualTilde}',
 '≃': '{\\simeq}',
 '≄': '{\\not\\simeq}',
 '≅': '{\\cong}',
 '≆': '{\\approxnotequal}',
 '≇': '{\\not\\cong}',
 '≈': '{\\approx}',
 '≉': '{\\not\\approx}',
 '≊': '{\\approxeq}',
 '≋': '{\\tildetrpl}',
 '≋̸': '{\\not\\apid}',
 '≌': '{\\allequal}',
 '≍': '{\\asymp}',
 '≎': '{\\Bumpeq}',
 '≎̸': '{\\NotHumpDownHump}',
 '≏': '{\\bumpeq}',
 '≏̸': '{\\NotHumpEqual}',
 '≐': '{\\doteq}',
 '≐̸': '{\\not\\doteq}',
 '≑': '{\\doteqdot}',
 '≒': '{\\fallingdotseq}',
 '≓': '{\\risingdotseq}',
 '≔': ':=',
 '≕': '=:',
 '≖': '{\\eqcirc}',
 '≗': '{\\circeq}',
 '≙': '{\\estimates}',
 '≚': '\\ElsevierGlyph{225A}',
 '≛': '{\\starequal}',
 '≜': '{\\triangleq}',
 '≟': '\\ElsevierGlyph{225F}',
 '≠': '\\not =',
 '≡': '{\\equiv}',
 '≢': '{\\not\\equiv}',
 '≤': '{\\leq}',
 '≥': '{\\geq}',
 '≦': '{\\leqq}',
 '≧': '{\\geqq}',
 '≨': '{\\lneqq}',
 '≨︀': '{\\lvertneqq}',
 '≩': '{\\gneqq}',
 '≩︀': '{\\gvertneqq}',
 '≪': '{\\ll}',
 '≪̸': '{\\NotLessLess}',
 '≫': '{\\gg}',
 '≫̸': '{\\NotGreaterGreater}',
 '≬': '{\\between}',
 '≭': '{\\not\\kern-0.3em\\times}',
 '≮': '\\not<',
 '≯': '\\not>',
 '≰': '{\\not\\leq}',
 '≱': '{\\not\\geq}',
 '≲': '{\\lessequivlnt}',
 '≳': '{\\greaterequivlnt}',
 '≴': '\\ElsevierGlyph{2274}',
 '≵': '\\ElsevierGlyph{2275}',
 '≶': '{\\lessgtr}',
 '≷': '{\\gtrless}',
 '≸': '{\\notlessgreater}',
 '≹': '{\\notgreaterless}',
 '≺': '{\\prec}',
 '≻': '{\\succ}',
 '≼': '{\\preccurlyeq}',
 '≽': '{\\succcurlyeq}',
 '≾': '{\\precapprox}',
 '≾̸': '{\\NotPrecedesTilde}',
 '≿': '{\\succapprox}',
 '≿̸': '{\\NotSucceedsTilde}',
 '⊀': '{\\not\\prec}',
 '⊁': '{\\not\\succ}',
 '⊂': '{\\subset}',
 '⊃': '{\\supset}',
 '⊄': '{\\not\\subset}',
 '⊅': '{\\not\\supset}',
 '⊆': '{\\subseteq}',
 '⊇': '{\\supseteq}',
 '⊈': '{\\not\\subseteq}',
 '⊉': '{\\not\\supseteq}',
 '⊊': '{\\subsetneq}',
 '⊊︀': '{\\varsubsetneqq}',
 '⊋': '{\\supsetneq}',
 '⊋︀': '{\\varsupsetneq}',
 '⊎': '{\\uplus}',
 '⊏': '{\\sqsubset}',
 '⊏̸': '{\\NotSquareSubset}',
 '⊐': '{\\sqsupset}',
 '⊐̸': '{\\NotSquareSuperset}',
 '⊑': '{\\sqsubseteq}',
 '⊒': '{\\sqsupseteq}',
 '⊓': '{\\sqcap}',
 '⊔': '{\\sqcup}',
 '⊕': '{\\oplus}',
 '⊖': '{\\ominus}',
 '⊗': '{\\otimes}',
 '⊘': '{\\oslash}',
 '⊙': '{\\odot}',
 '⊚': '{\\circledcirc}',
 '⊛': '{\\circledast}',
 '⊝': '{\\circleddash}',
 '⊞': '{\\boxplus}',
 '⊟': '{\\boxminus}',
 '⊠': '{\\boxtimes}',
 '⊡': '{\\boxdot}',
 '⊢': '{\\vdash}',
 '⊣': '{\\dashv}',
 '⊤': '{\\top}',
 '⊥': '{\\perp}',
 '⊧': '{\\truestate}',
 '⊨': '{\\forcesextra}',
 '⊩': '{\\Vdash}',
 '⊪': '{\\Vvdash}',
 '⊫': '{\\VDash}',
 '⊬': '{\\nvdash}',
 '⊭': '{\\nvDash}',
 '⊮': '{\\nVdash}',
 '⊯': '{\\nVDash}',
 '⊲': '{\\vartriangleleft}',
 '⊳': '{\\vartriangleright}',
 '⊴': '{\\trianglelefteq}',
 '⊵': '{\\trianglerighteq}',
 '⊶': '{\\original}',
 '⊷': '{\\image}',
 '⊸': '{\\multimap}',
 '⊹': '{\\hermitconjmatrix}',
 '⊺': '{\\intercal}',
 '⊻': '{\\veebar}',
 '⊾': '{\\rightanglearc}',
 '⋀': '\\ElsevierGlyph{22C0}',
 '⋁': '\\ElsevierGlyph{22C1}',
 '⋂': '{\\bigcap}',
 '⋃': '{\\bigcup}',
 '⋄': '{\\diamond}',
 '⋅': '{\\cdot}',
 '⋆': '{\\star}',
 '⋇': '{\\divideontimes}',
 '⋈': '{\\bowtie}',
 '⋉': '{\\ltimes}',
 '⋊': '{\\rtimes}',
 '⋋': '{\\leftthreetimes}',
 '⋌': '{\\rightthreetimes}',
 '⋍': '{\\backsimeq}',
 '⋎': '{\\curlyvee}',
 '⋏': '{\\curlywedge}',
 '⋐': '{\\Subset}',
 '⋑': '{\\Supset}',
 '⋒': '{\\Cap}',
 '⋓': '{\\Cup}',
 '⋔': '{\\pitchfork}',
 '⋖': '{\\lessdot}',
 '⋗': '{\\gtrdot}',
 '⋘': '{\\verymuchless}',
 '⋙': '{\\verymuchgreater}',
 '⋚': '{\\lesseqgtr}',
 '⋛': '{\\gtreqless}',
 '⋞': '{\\curlyeqprec}',
 '⋟': '{\\curlyeqsucc}',
 '⋢': '{\\not\\sqsubseteq}',
 '⋣': '{\\not\\sqsupseteq}',
 '⋥': '{\\Elzsqspne}',
 '⋦': '{\\lnsim}',
 '⋧': '{\\gnsim}',
 '⋨': '{\\precedesnotsimilar}',
 '⋩': '{\\succnsim}',
 '⋪': '{\\ntriangleleft}',
 '⋫': '{\\ntriangleright}',
 '⋬': '{\\ntrianglelefteq}',
 '⋭': '{\\ntrianglerighteq}',
 '⋮': '{\\vdots}',
 '⋯': '{\\cdots}',
 '⋰': '{\\upslopeellipsis}',
 '⋱': '{\\downslopeellipsis}',
 '⌅': '{\\barwedge}',
 '⌆': '{\\perspcorrespond}',
 '⌈': '{\\lceil}',
 '⌉': '{\\rceil}',
 '⌊': '{\\lfloor}',
 '⌋': '{\\rfloor}',
 '⌕': '{\\recorder}',
 '⌖': '\\mathchar"2208',
 '⌜': '{\\ulcorner}',
 '⌝': '{\\urcorner}',
 '⌞': '{\\llcorner}',
 '⌟': '{\\lrcorner}',
 '⌢': '{\\frown}',
 '⌣': '{\\smile}',
 '〈': '{\\langle}',
 '〉': '{\\rangle}',
 '⌽': '\\ElsevierGlyph{E838}',
 '⎣': '{\\Elzdlcorn}',
 '⎰': '{\\lmoustache}',
 '⎱': '{\\rmoustache}',
 '␣': '{\\textvisiblespace}',
 '①': '\\ding{172}',
 '②': '\\ding{173}',
 '③': '\\ding{174}',
 '④': '\\ding{175}',
 '⑤': '\\ding{176}',
 '⑥': '\\ding{177}',
 '⑦': '\\ding{178}',
 '⑧': '\\ding{179}',
 '⑨': '\\ding{180}',
 '⑩': '\\ding{181}',
 'Ⓢ': '{\\circledS}',
 '┆': '{\\Elzdshfnc}',
 '┙': '{\\Elzsqfnw}',
 '╱': '{\\diagup}',
 '■': '\\ding{110}',
 '□': '{\\square}',
 '▪': '{\\blacksquare}',
 '▭': '\\fbox{~~}',
 '▯': '{\\Elzvrecto}',
 '▱': '\\ElsevierGlyph{E381}',
 '▲': '\\ding{115}',
 '△': '{\\bigtriangleup}',
 '▴': '{\\blacktriangle}',
 '▵': '{\\vartriangle}',
 '▸': '{\\blacktriangleright}',
 '▹': '{\\triangleright}',
 '▼': '\\ding{116}',
 '▽': '{\\bigtriangledown}',
 '▾': '{\\blacktriangledown}',
 '▿': '{\\triangledown}',
 '◂': '{\\blacktriangleleft}',
 '◃': '{\\triangleleft}',
 '◆': '\\ding{117}',
 '◊': '{\\lozenge}',
 '○': '{\\bigcirc}',
 '●': '\\ding{108}',
 '◐': '{\\Elzcirfl}',
 '◑': '{\\Elzcirfr}',
 '◒': '{\\Elzcirfb}',
 '◗': '\\ding{119}',
 '◘': '{\\Elzrvbull}',
 '◧': '{\\Elzsqfl}',
 '◨': '{\\Elzsqfr}',
 '◪': '{\\Elzsqfse}',
 '◯': '{\\bigcirc}',
 '★': '\\ding{72}',
 '☆': '\\ding{73}',
 '☎': '\\ding{37}',
 '☛': '\\ding{42}',
 '☞': '\\ding{43}',
 '☾': '{\\rightmoon}',
 '☿': '{\\mercury}',
 '♀': '{\\venus}',
 '♂': '{\\male}',
 '♃': '{\\jupiter}',
 '♄': '{\\saturn}',
 '♅': '{\\uranus}',
 '♆': '{\\neptune}',
 '♇': '{\\pluto}',
 '♈': '{\\aries}',
 '♉': '{\\taurus}',
 '♊': '{\\gemini}',
 '♋': '{\\cancer}',
 '♌': '{\\leo}',
 '♍': '{\\virgo}',
 '♎': '{\\libra}',
 '♏': '{\\scorpio}',
 '♐': '{\\sagittarius}',
 '♑': '{\\capricornus}',
 '♒': '{\\aquarius}',
 '♓': '{\\pisces}',
 '♠': '\\ding{171}',
 '♢': '{\\diamond}',
 '♣': '\\ding{168}',
 '♥': '\\ding{170}',
 '♦': '\\ding{169}',
 '♩': '{\\quarternote}',
 '♪': '{\\eighthnote}',
 '♭': '{\\flat}',
 '♮': '{\\natural}',
 '♯': '{\\sharp}',
 '✁': '\\ding{33}',
 '✂': '\\ding{34}',
 '✃': '\\ding{35}',
 '✄': '\\ding{36}',
 '✆': '\\ding{38}',
 '✇': '\\ding{39}',
 '✈': '\\ding{40}',
 '✉': '\\ding{41}',
 '✌': '\\ding{44}',
 '✍': '\\ding{45}',
 '✎': '\\ding{46}',
 '✏': '\\ding{47}',
 '✐': '\\ding{48}',
 '✑': '\\ding{49}',
 '✒': '\\ding{50}',
 '✓': '\\ding{51}',
 '✔': '\\ding{52}',
 '✕': '\\ding{53}',
 '✖': '\\ding{54}',
 '✗': '\\ding{55}',
 '✘': '\\ding{56}',
 '✙': '\\ding{57}',
 '✚': '\\ding{58}',
 '✛': '\\ding{59}',
 '✜': '\\ding{60}',
 '✝': '\\ding{61}',
 '✞': '\\ding{62}',
 '✟': '\\ding{63}',
 '✠': '\\ding{64}',
 '✡': '\\ding{65}',
 '✢': '\\ding{66}',
 '✣': '\\ding{67}',
 '✤': '\\ding{68}',
 '✥': '\\ding{69}',
 '✦': '\\ding{70}',
 '✧': '\\ding{71}',
 '✩': '\\ding{73}',
 '✪': '\\ding{74}',
 '✫': '\\ding{75}',
 '✬': '\\ding{76}',
 '✭': '\\ding{77}',
 '✮': '\\ding{78}',
 '✯': '\\ding{79}',
 '✰': '\\ding{80}',
 '✱': '\\ding{81}',
 '✲': '\\ding{82}',
 '✳': '\\ding{83}',
 '✴': '\\ding{84}',
 '✵': '\\ding{85}',
 '✶': '\\ding{86}',
 '✷': '\\ding{87}',
 '✸': '\\ding{88}',
 '✹': '\\ding{89}',
 '✺': '\\ding{90}',
 '✻': '\\ding{91}',
 '✼': '\\ding{92}',
 '✽': '\\ding{93}',
 '✾': '\\ding{94}',
 '✿': '\\ding{95}',
 '❀': '\\ding{96}',
 '❁': '\\ding{97}',
 '❂': '\\ding{98}',
 '❃': '\\ding{99}',
 '❄': '\\ding{100}',
 '❅': '\\ding{101}',
 '❆': '\\ding{102}',
 '❇': '\\ding{103}',
 '❈': '\\ding{104}',
 '❉': '\\ding{105}',
 '❊': '\\ding{106}',
 '❋': '\\ding{107}',
 '❍': '\\ding{109}',
 '❏': '\\ding{111}',
 '❐': '\\ding{112}',
 '❑': '\\ding{113}',
 '❒': '\\ding{114}',
 '❖': '\\ding{118}',
 '❘': '\\ding{120}',
 '❙': '\\ding{121}',
 '❚': '\\ding{122}',
 '❛': '\\ding{123}',
 '❜': '\\ding{124}',
 '❝': '\\ding{125}',
 '❞': '\\ding{126}',
 '❡': '\\ding{161}',
 '❢': '\\ding{162}',
 '❣': '\\ding{163}',
 '❤': '\\ding{164}',
 '❥': '\\ding{165}',
 '❦': '\\ding{166}',
 '❧': '\\ding{167}',
 '❶': '\\ding{182}',
 '❷': '\\ding{183}',
 '❸': '\\ding{184}',
 '❹': '\\ding{185}',
 '❺': '\\ding{186}',
 '❻': '\\ding{187}',
 '❼': '\\ding{188}',
 '❽': '\\ding{189}',
 '❾': '\\ding{190}',
 '❿': '\\ding{191}',
 '➀': '\\ding{192}',
 '➁': '\\ding{193}',
 '➂': '\\ding{194}',
 '➃': '\\ding{195}',
 '➄': '\\ding{196}',
 '➅': '\\ding{197}',
 '➆': '\\ding{198}',
 '➇': '\\ding{199}',
 '➈': '\\ding{200}',
 '➉': '\\ding{201}',
 '➊': '\\ding{202}',
 '➋': '\\ding{203}',
 '➌': '\\ding{204}',
 '➍': '\\ding{205}',
 '➎': '\\ding{206}',
 '➏': '\\ding{207}',
 '➐': '\\ding{208}',
 '➑': '\\ding{209}',
 '➒': '\\ding{210}',
 '➓': '\\ding{211}',
 '➔': '\\ding{212}',
 '➘': '\\ding{216}',
 '➙': '\\ding{217}',
 '➚': '\\ding{218}',
 '➛': '\\ding{219}',
 '➜': '\\ding{220}',
 '➝': '\\ding{221}',
 '➞': '\\ding{222}',
 '➟': '\\ding{223}',
 '➠': '\\ding{224}',
 '➡': '\\ding{225}',
 '➢': '\\ding{226}',
 '➣': '\\ding{227}',
 '➤': '\\ding{228}',
 '➥': '\\ding{229}',
 '➦': '\\ding{230}',
 '➧': '\\ding{231}',
 '➨': '\\ding{232}',
 '➩': '\\ding{233}',
 '➪': '\\ding{234}',
 '➫': '\\ding{235}',
 '➬': '\\ding{236}',
 '➭': '\\ding{237}',
 '➮': '\\ding{238}',
 '➯': '\\ding{239}',
 '➱': '\\ding{241}',
 '➲': '\\ding{242}',
 '➳': '\\ding{243}',
 '➴': '\\ding{244}',
 '➵': '\\ding{245}',
 '➶': '\\ding{246}',
 '➷': '\\ding{247}',
 '➸': '\\ding{248}',
 '➹': '\\ding{249}',
 '➺': '\\ding{250}',
 '➻': '\\ding{251}',
 '➼': '\\ding{252}',
 '➽': '\\ding{253}',
 '➾': '\\ding{254}',
 '⟵': '{\\longleftarrow}',
 '⟶': '{\\longrightarrow}',
 '⟷': '{\\longleftrightarrow}',
 '⟸': '{\\Longleftarrow}',
 '⟹': '{\\Longrightarrow}',
 '⟺': '{\\Longleftrightarrow}',
 '⟼': '{\\longmapsto}',
 '⟿': '{\\sim\\joinrel\\leadsto}',
 '⤅': '\\ElsevierGlyph{E212}',
 '⤒': '{\\UpArrowBar}',
 '⤓': '{\\DownArrowBar}',
 '⤣': '\\ElsevierGlyph{E20C}',
 '⤤': '\\ElsevierGlyph{E20D}',
 '⤥': '\\ElsevierGlyph{E20B}',
 '⤦': '\\ElsevierGlyph{E20A}',
 '⤧': '\\ElsevierGlyph{E211}',
 '⤨': '\\ElsevierGlyph{E20E}',
 '⤩': '\\ElsevierGlyph{E20F}',
 '⤪': '\\ElsevierGlyph{E210}',
 '⤳': '\\ElsevierGlyph{E21C}',
 '⤳̸': '\\ElsevierGlyph{E21D}',
 '⤶': '\\ElsevierGlyph{E21A}',
 '⤷': '\\ElsevierGlyph{E219}',
 '⥀': '{\\Elolarr}',
 '⥁': '{\\Elorarr}',
 '⥂': '{\\ElzRlarr}',
 '⥄': '{\\ElzrLarr}',
 '⥇': '{\\Elzrarrx}',
 '⥎': '{\\LeftRightVector}',
 '⥏': '{\\RightUpDownVector}',
 '⥐': '{\\DownLeftRightVector}',
 '⥑': '{\\LeftUpDownVector}',
 '⥒': '{\\LeftVectorBar}',
 '⥓': '{\\RightVectorBar}',
 '⥔': '{\\RightUpVectorBar}',
 '⥕': '{\\RightDownVectorBar}',
 '⥖': '{\\DownLeftVectorBar}',
 '⥗': '{\\DownRightVectorBar}',
 '⥘': '{\\LeftUpVectorBar}',
 '⥙': '{\\LeftDownVectorBar}',
 '⥚': '{\\LeftTeeVector}',
 '⥛': '{\\RightTeeVector}',
 '⥜': '{\\RightUpTeeVector}',
 '⥝': '{\\RightDownTeeVector}',
 '⥞': '{\\DownLeftTeeVector}',
 '⥟': '{\\DownRightTeeVector}',
 '⥠': '{\\LeftUpTeeVector}',
 '⥡': '{\\LeftDownTeeVector}',
 '⥮': '{\\UpEquilibrium}',
 '⥯': '{\\ReverseUpEquilibrium}',
 '⥰': '{\\RoundImplies}',
 '⥼': '\\ElsevierGlyph{E214}',
 '⥽': '\\ElsevierGlyph{E215}',
 '⦀': '{\\Elztfnc}',
 '⦅': '\\ElsevierGlyph{3018}',
 '⦆': '{\\Elroang}',
 '⦓': '<\\kern-0.58em(',
 '⦔': '\\ElsevierGlyph{E291}',
 '⦙': '{\\Elzddfnc}',
 '⦜': '{\\Angle}',
 '⦠': '{\\Elzlpargt}',
 '⦵': '\\ElsevierGlyph{E260}',
 '⦶': '\\ElsevierGlyph{E61B}',
 '⧊': '{\\ElzLap}',
 '⧋': '{\\Elzdefas}',
 '⧏': '{\\LeftTriangleBar}',
 '⧏̸': '{\\NotLeftTriangleBar}',
 '⧐': '{\\RightTriangleBar}',
 '⧐̸': '{\\NotRightTriangleBar}',
 '⧜': '\\ElsevierGlyph{E372}',
 '⧫': '{\\blacklozenge}',
 '⧴': '{\\RuleDelayed}',
 '⨄': '{\\Elxuplus}',
 '⨅': '{\\ElzThr}',
 '⨆': '{\\Elxsqcup}',
 '⨇': '{\\ElzInf}',
 '⨈': '{\\ElzSup}',
 '⨍': '{\\ElzCint}',
 '⨏': '{\\clockoint}',
 '⨐': '\\ElsevierGlyph{E395}',
 '⨖': '{\\sqrint}',
 '⨥': '\\ElsevierGlyph{E25A}',
 '⨪': '\\ElsevierGlyph{E25B}',
 '⨭': '\\ElsevierGlyph{E25C}',
 '⨮': '\\ElsevierGlyph{E25D}',
 '⨯': '{\\ElzTimes}',
 '⨴': '\\ElsevierGlyph{E25E}',
 '⨵': '\\ElsevierGlyph{E25E}',
 '⨼': '\\ElsevierGlyph{E259}',
 '⨿': '{\\amalg}',
 '⩓': '{\\ElzAnd}',
 '⩔': '{\\ElzOr}',
 '⩕': '\\ElsevierGlyph{E36E}',
 '⩖': '{\\ElOr}',
 '⩞': '{\\perspcorrespond}',
 '⩟': '{\\Elzminhat}',
 '⩣': '\\ElsevierGlyph{225A}',
 '⩮': '\\stackrel{*}{=}',
 '⩵': '{\\Equal}',
 '⩽': '{\\leqslant}',
 '⩽̸': '{\\nleqslant}',
 '⩾': '{\\geqslant}',
 '⩾̸': '{\\ngeqslant}',
 '⪅': '{\\lessapprox}',
 '⪆': '{\\gtrapprox}',
 '⪇': '{\\lneq}',
 '⪈': '{\\gneq}',
 '⪉': '{\\lnapprox}',
 '⪊': '{\\gnapprox}',
 '⪋': '{\\lesseqqgtr}',
 '⪌': '{\\gtreqqless}',
 '⪕': '{\\eqslantless}',
 '⪖': '{\\eqslantgtr}',
 '⪝': '\\Pisymbol{ppi020}{117}',
 '⪞': '\\Pisymbol{ppi020}{105}',
 '⪡': '{\\NestedLessLess}',
 '⪡̸': '{\\NotNestedLessLess}',
 '⪢': '{\\NestedGreaterGreater}',
 '⪢̸': '{\\NotNestedGreaterGreater}',
 '⪯': '{\\preceq}',
 '⪯̸': '{\\not\\preceq}',
 '⪰': '{\\succeq}',
 '⪰̸': '{\\not\\succeq}',
 '⪵': '{\\precneqq}',
 '⪶': '{\\succneqq}',
 '⪷': '{\\precapprox}',
 '⪸': '{\\succapprox}',
 '⪹': '{\\precnapprox}',
 '⪺': '{\\succnapprox}',
 '⫅': '{\\subseteqq}',
 '⫅̸': '{\\nsubseteqq}',
 '⫆': '{\\supseteqq}',
 '⫆̸': '{\\nsupseteqq}',
 '⫋': '{\\subsetneqq}',
 '⫌': '{\\supsetneqq}',
 '⫫': '\\ElsevierGlyph{E30D}',
 '⫶': '{\\Elztdcol}',
 '⫽': '${/}\\!\\!{/}$',
 '⫽⃥': '{\\rlap{\\textbackslash}{{/}\\!\\!{/}}}',
 '《': '\\ElsevierGlyph{300A}',
 '》': '\\ElsevierGlyph{300B}',
 '〘': '\\ElsevierGlyph{3018}',
 '〙': '\\ElsevierGlyph{3019}',
 '〚': '{\\openbracketleft}',
 '〛': '{\\openbracketright}',
 'ﬀ': 'ff',
 'ﬁ': 'fi',
 'ﬂ': 'fl',
 'ﬃ': 'ffi',
 'ﬄ': 'ffl',
 '𝐀': '\\mathbf{A}',
 '𝐁': '\\mathbf{B}',
 '𝐂': '\\mathbf{C}',
 '𝐃': '\\mathbf{D}',
 '𝐄': '\\mathbf{E}',
 '𝐅': '\\mathbf{F}',
 '𝐆': '\\mathbf{G}',
 '𝐇': '\\mathbf{H}',
 '𝐈': '\\mathbf{I}',
 '𝐉': '\\mathbf{J}',
 '𝐊': '\\mathbf{K}',
 '𝐋': '\\mathbf{L}',
 '𝐌': '\\mathbf{M}',
 '𝐍': '\\mathbf{N}',
 '𝐎': '\\mathbf{O}',
 '𝐏': '\\mathbf{P}',
 '𝐐': '\\mathbf{Q}',
 '𝐑': '\\mathbf{R}',
 '𝐒': '\\mathbf{S}',
 '𝐓': '\\mathbf{T}',
 '𝐔': '\\mathbf{U}',
 '𝐕': '\\mathbf{V}',
 '𝐖': '\\mathbf{W}',
 '𝐗': '\\mathbf{X}',
 '𝐘': '\\mathbf{Y}',
 '𝐙': '\\mathbf{Z}',
 '𝐚': '\\mathbf{a}',
 '𝐛': '\\mathbf{b}',
 '𝐜': '\\mathbf{c}',
 '𝐝': '\\mathbf{d}',
 '𝐞': '\\mathbf{e}',
 '𝐟': '\\mathbf{f}',
 '𝐠': '\\mathbf{g}',
 '𝐡': '\\mathbf{h}',
 '𝐢': '\\mathbf{i}',
 '𝐣': '\\mathbf{j}',
 '𝐤': '\\mathbf{k}',
 '𝐥': '\\mathbf{l}',
 '𝐦': '\\mathbf{m}',
 '𝐧': '\\mathbf{n}',
 '𝐨': '\\mathbf{o}',
 '𝐩': '\\mathbf{p}',
 '𝐪': '\\mathbf{q}',
 '𝐫': '\\mathbf{r}',
 '𝐬': '\\mathbf{s}',
 '𝐭': '\\mathbf{t}',
 '𝐮': '\\mathbf{u}',
 '𝐯': '\\mathbf{v}',
 '𝐰': '\\mathbf{w}',
 '𝐱': '\\mathbf{x}',
 '𝐲': '\\mathbf{y}',
 '𝐳': '\\mathbf{z}',
 '𝐴': '\\mathsl{A}',
 '𝐵': '\\mathsl{B}',
 '𝐶': '\\mathsl{C}',
 '𝐷': '\\mathsl{D}',
 '𝐸': '\\mathsl{E}',
 '𝐹': '\\mathsl{F}',
 '𝐺': '\\mathsl{G}',
 '𝐻': '\\mathsl{H}',
 '𝐼': '\\mathsl{I}',
 '𝐽': '\\mathsl{J}',
 '𝐾': '\\mathsl{K}',
 '𝐿': '\\mathsl{L}',
 '𝑀': '\\mathsl{M}',
 '𝑁': '\\mathsl{N}',
 '𝑂': '\\mathsl{O}',
 '𝑃': '\\mathsl{P}',
 '𝑄': '\\mathsl{Q}',
 '𝑅': '\\mathsl{R}',
 '𝑆': '\\mathsl{S}',
 '𝑇': '\\mathsl{T}',
 '𝑈': '\\mathsl{U}',
 '𝑉': '\\mathsl{V}',
 '𝑊': '\\mathsl{W}',
 '𝑋': '\\mathsl{X}',
 '𝑌': '\\mathsl{Y}',
 '𝑍': '\\mathsl{Z}',
 '𝑎': '\\mathsl{a}',
 '𝑏': '\\mathsl{b}',
 '𝑐': '\\mathsl{c}',
 '𝑑': '\\mathsl{d}',
 '𝑒': '\\mathsl{e}',
 '𝑓': '\\mathsl{f}',
 '𝑔': '\\mathsl{g}',
 '𝑖': '\\mathsl{i}',
 '𝑗': '\\mathsl{j}',
 '𝑘': '\\mathsl{k}',
 '𝑙': '\\mathsl{l}',
 '𝑚': '\\mathsl{m}',
 '𝑛': '\\mathsl{n}',
 '𝑜': '\\mathsl{o}',
 '𝑝': '\\mathsl{p}',
 '𝑞': '\\mathsl{q}',
 '𝑟': '\\mathsl{r}',
 '𝑠': '\\mathsl{s}',
 '𝑡': '\\mathsl{t}',
 '𝑢': '\\mathsl{u}',
 '𝑣': '\\mathsl{v}',
 '𝑤': '\\mathsl{w}',
 '𝑥': '\\mathsl{x}',
 '𝑦': '\\mathsl{y}',
 '𝑧': '\\mathsl{z}',
 '𝑨': '\\mathbit{A}',
 '𝑩': '\\mathbit{B}',
 '𝑪': '\\mathbit{C}',
 '𝑫': '\\mathbit{D}',
 '𝑬': '\\mathbit{E}',
 '𝑭': '\\mathbit{F}',
 '𝑮': '\\mathbit{G}',
 '𝑯': '\\mathbit{H}',
 '𝑰': '\\mathbit{I}',
 '𝑱': '\\mathbit{J}',
 '𝑲': '\\mathbit{K}',
 '𝑳': '\\mathbit{L}',
 '𝑴': '\\mathbit{M}',
 '𝑵': '\\mathbit{N}',
 '𝑶': '\\mathbit{O}',
 '𝑷': '\\mathbit{P}',
 '𝑸': '\\mathbit{Q}',
 '𝑹': '\\mathbit{R}',
 '𝑺': '\\mathbit{S}',
 '𝑻': '\\mathbit{T}',
 '𝑼': '\\mathbit{U}',
 '𝑽': '\\mathbit{V}',
 '𝑾': '\\mathbit{W}',
 '𝑿': '\\mathbit{X}',
 '𝒀': '\\mathbit{Y}',
 '𝒁': '\\mathbit{Z}',
 '𝒂': '\\mathbit{a}',
 '𝒃': '\\mathbit{b}',
 '𝒄': '\\mathbit{c}',
 '𝒅': '\\mathbit{d}',
 '𝒆': '\\mathbit{e}',
 '𝒇': '\\mathbit{f}',
 '𝒈': '\\mathbit{g}',
 '𝒉': '\\mathbit{h}',
 '𝒊': '\\mathbit{i}',
 '𝒋': '\\mathbit{j}',
 '𝒌': '\\mathbit{k}',
 '𝒍': '\\mathbit{l}',
 '𝒎': '\\mathbit{m}',
 '𝒏': '\\mathbit{n}',
 '𝒐': '\\mathbit{o}',
 '𝒑': '\\mathbit{p}',
 '𝒒': '\\mathbit{q}',
 '𝒓': '\\mathbit{r}',
 '𝒔': '\\mathbit{s}',
 '𝒕': '\\mathbit{t}',
 '𝒖': '\\mathbit{u}',
 '𝒗': '\\mathbit{v}',
 '𝒘': '\\mathbit{w}',
 '𝒙': '\\mathbit{x}',
 '𝒚': '\\mathbit{y}',
 '𝒛': '\\mathbit{z}',
 '𝒜': '\\mathscr{A}',
 '𝒞': '\\mathscr{C}',
 '𝒟': '\\mathscr{D}',
 '𝒢': '\\mathscr{G}',
 '𝒥': '\\mathscr{J}',
 '𝒦': '\\mathscr{K}',
 '𝒩': '\\mathscr{N}',
 '𝒪': '\\mathscr{O}',
 '𝒫': '\\mathscr{P}',
 '𝒬': '\\mathscr{Q}',
 '𝒮': '\\mathscr{S}',
 '𝒯': '\\mathscr{T}',
 '𝒰': '\\mathscr{U}',
 '𝒱': '\\mathscr{V}',
 '𝒲': '\\mathscr{W}',
 '𝒳': '\\mathscr{X}',
 '𝒴': '\\mathscr{Y}',
 '𝒵': '\\mathscr{Z}',
 '𝒶': '\\mathscr{a}',
 '𝒷': '\\mathscr{b}',
 '𝒸': '\\mathscr{c}',
 '𝒹': '\\mathscr{d}',
 '𝒻': '\\mathscr{f}',
 '𝒽': '\\mathscr{h}',
 '𝒾': '\\mathscr{i}',
 '𝒿': '\\mathscr{j}',
 '𝓀': '\\mathscr{k}',
 '𝓁': '\\mathscr{l}',
 '𝓂': '\\mathscr{m}',
 '𝓃': '\\mathscr{n}',
 '𝓅': '\\mathscr{p}',
 '𝓆': '\\mathscr{q}',
 '𝓇': '\\mathscr{r}',
 '𝓈': '\\mathscr{s}',
 '𝓉': '\\mathscr{t}',
 '𝓊': '\\mathscr{u}',
 '𝓋': '\\mathscr{v}',
 '𝓌': '\\mathscr{w}',
 '𝓍': '\\mathscr{x}',
 '𝓎': '\\mathscr{y}',
 '𝓏': '\\mathscr{z}',
 '𝓐': '\\mathmit{A}',
 '𝓑': '\\mathmit{B}',
 '𝓒': '\\mathmit{C}',
 '𝓓': '\\mathmit{D}',
 '𝓔': '\\mathmit{E}',
 '𝓕': '\\mathmit{F}',
 '𝓖': '\\mathmit{G}',
 '𝓗': '\\mathmit{H}',
 '𝓘': '\\mathmit{I}',
 '𝓙': '\\mathmit{J}',
 '𝓚': '\\mathmit{K}',
 '𝓛': '\\mathmit{L}',
 '𝓜': '\\mathmit{M}',
 '𝓝': '\\mathmit{N}',
 '𝓞': '\\mathmit{O}',
 '𝓟': '\\mathmit{P}',
 '𝓠': '\\mathmit{Q}',
 '𝓡': '\\mathmit{R}',
 '𝓢': '\\mathmit{S}',
 '𝓣': '\\mathmit{T}',
 '𝓤': '\\mathmit{U}',
 '𝓥': '\\mathmit{V}',
 '𝓦': '\\mathmit{W}',
 '𝓧': '\\mathmit{X}',
 '𝓨': '\\mathmit{Y}',
 '𝓩': '\\mathmit{Z}',
 '𝓪': '\\mathmit{a}',
 '𝓫': '\\mathmit{b}',
 '𝓬': '\\mathmit{c}',
 '𝓭': '\\mathmit{d}',
 '𝓮': '\\mathmit{e}',
 '𝓯': '\\mathmit{f}',
 '𝓰': '\\mathmit{g}',
 '𝓱': '\\mathmit{h}',
 '𝓲': '\\mathmit{i}',
 '𝓳': '\\mathmit{j}',
 '𝓴': '\\mathmit{k}',
 '𝓵': '\\mathmit{l}',
 '𝓶': '\\mathmit{m}',
 '𝓷': '\\mathmit{n}',
 '𝓸': '\\mathmit{o}',
 '𝓹': '\\mathmit{p}',
 '𝓺': '\\mathmit{q}',
 '𝓻': '\\mathmit{r}',
 '𝓼': '\\mathmit{s}',
 '𝓽': '\\mathmit{t}',
 '𝓾': '\\mathmit{u}',
 '𝓿': '\\mathmit{v}',
 '𝔀': '\\mathmit{w}',
 '𝔁': '\\mathmit{x}',
 '𝔂': '\\mathmit{y}',
 '𝔃': '\\mathmit{z}',
 '𝔄': '\\mathfrak{A}',
 '𝔅': '\\mathfrak{B}',
 '𝔇': '\\mathfrak{D}',
 '𝔈': '\\mathfrak{E}',
 '𝔉': '\\mathfrak{F}',
 '𝔊': '\\mathfrak{G}',
 '𝔍': '\\mathfrak{J}',
 '𝔎': '\\mathfrak{K}',
 '𝔏': '\\mathfrak{L}',
 '𝔐': '\\mathfrak{M}',
 '𝔑': '\\mathfrak{N}',
 '𝔒': '\\mathfrak{O}',
 '𝔓': '\\mathfrak{P}',
 '𝔔': '\\mathfrak{Q}',
 '𝔖': '\\mathfrak{S}',
 '𝔗': '\\mathfrak{T}',
 '𝔘': '\\mathfrak{U}',
 '𝔙': '\\mathfrak{V}',
 '𝔚': '\\mathfrak{W}',
 '𝔛': '\\mathfrak{X}',
 '𝔜': '\\mathfrak{Y}',
 '𝔞': '\\mathfrak{a}',
 '𝔟': '\\mathfrak{b}',
 '𝔠': '\\mathfrak{c}',
 '𝔡': '\\mathfrak{d}',
 '𝔢': '\\mathfrak{e}',
 '𝔣': '\\mathfrak{f}',
 '𝔤': '\\mathfrak{g}',
 '𝔥': '\\mathfrak{h}',
 '𝔦': '\\mathfrak{i}',
 '𝔧': '\\mathfrak{j}',
 '𝔨': '\\mathfrak{k}',
 '𝔩': '\\mathfrak{l}',
 '𝔪': '\\mathfrak{m}',
 '𝔫': '\\mathfrak{n}',
 '𝔬': '\\mathfrak{o}',
 '𝔭': '\\mathfrak{p}',
 '𝔮': '\\mathfrak{q}',
 '𝔯': '\\mathfrak{r}',
 '𝔰': '\\mathfrak{s}',
 '𝔱': '\\mathfrak{t}',
 '𝔲': '\\mathfrak{u}',
 '𝔳': '\\mathfrak{v}',
 '𝔴': '\\mathfrak{w}',
 '𝔵': '\\mathfrak{x}',
 '𝔶': '\\mathfrak{y}',
 '𝔷': '\\mathfrak{z}',
 '𝔸': '\\mathbb{A}',
 '𝔹': '\\mathbb{B}',
 '𝔻': '\\mathbb{D}',
 '𝔼': '\\mathbb{E}',
 '𝔽': '\\mathbb{F}',
 '𝔾': '\\mathbb{G}',
 '𝕀': '\\mathbb{I}',
 '𝕁': '\\mathbb{J}',
 '𝕂': '\\mathbb{K}',
 '𝕃': '\\mathbb{L}',
 '𝕄': '\\mathbb{M}',
 '𝕆': '\\mathbb{O}',
 '𝕊': '\\mathbb{S}',
 '𝕋': '\\mathbb{T}',
 '𝕌': '\\mathbb{U}',
 '𝕍': '\\mathbb{V}',
 '𝕎': '\\mathbb{W}',
 '𝕏': '\\mathbb{X}',
 '𝕐': '\\mathbb{Y}',
 '𝕒': '\\mathbb{a}',
 '𝕓': '\\mathbb{b}',
 '𝕔': '\\mathbb{c}',
 '𝕕': '\\mathbb{d}',
 '𝕖': '\\mathbb{e}',
 '𝕗': '\\mathbb{f}',
 '𝕘': '\\mathbb{g}',
 '𝕙': '\\mathbb{h}',
 '𝕚': '\\mathbb{i}',
 '𝕛': '\\mathbb{j}',
 '𝕜': '\\mathbb{k}',
 '𝕝': '\\mathbb{l}',
 '𝕞': '\\mathbb{m}',
 '𝕟': '\\mathbb{n}',
 '𝕠': '\\mathbb{o}',
 '𝕡': '\\mathbb{p}',
 '𝕢': '\\mathbb{q}',
 '𝕣': '\\mathbb{r}',
 '𝕤': '\\mathbb{s}',
 '𝕥': '\\mathbb{t}',
 '𝕦': '\\mathbb{u}',
 '𝕧': '\\mathbb{v}',
 '𝕨': '\\mathbb{w}',
 '𝕩': '\\mathbb{x}',
 '𝕪': '\\mathbb{y}',
 '𝕫': '\\mathbb{z}',
 '𝕬': '\\mathslbb{A}',
 '𝕭': '\\mathslbb{B}',
 '𝕮': '\\mathslbb{C}',
 '𝕯': '\\mathslbb{D}',
 '𝕰': '\\mathslbb{E}',
 '𝕱': '\\mathslbb{F}',
 '𝕲': '\\mathslbb{G}',
 '𝕳': '\\mathslbb{H}',
 '𝕴': '\\mathslbb{I}',
 '𝕵': '\\mathslbb{J}',
 '𝕶': '\\mathslbb{K}',
 '𝕷': '\\mathslbb{L}',
 '𝕸': '\\mathslbb{M}',
 '𝕹': '\\mathslbb{N}',
 '𝕺': '\\mathslbb{O}',
 '𝕻': '\\mathslbb{P}',
 '𝕼': '\\mathslbb{Q}',
 '𝕽': '\\mathslbb{R}',
 '𝕾': '\\mathslbb{S}',
 '𝕿': '\\mathslbb{T}',
 '𝖀': '\\mathslbb{U}',
 '𝖁': '\\mathslbb{V}',
 '𝖂': '\\mathslbb{W}',
 '𝖃': '\\mathslbb{X}',
 '𝖄': '\\mathslbb{Y}',
 '𝖅': '\\mathslbb{Z}',
 '𝖆': '\\mathslbb{a}',
 '𝖇': '\\mathslbb{b}',
 '𝖈': '\\mathslbb{c}',
 '𝖉': '\\mathslbb{d}',
 '𝖊': '\\mathslbb{e}',
 '𝖋': '\\mathslbb{f}',
 '𝖌': '\\mathslbb{g}',
 '𝖍': '\\mathslbb{h}',
 '𝖎': '\\mathslbb{i}',
 '𝖏': '\\mathslbb{j}',
 '𝖐': '\\mathslbb{k}',
 '𝖑': '\\mathslbb{l}',
 '𝖒': '\\mathslbb{m}',
 '𝖓': '\\mathslbb{n}',
 '𝖔': '\\mathslbb{o}',
 '𝖕': '\\mathslbb{p}',
 '𝖖': '\\mathslbb{q}',
 '𝖗': '\\mathslbb{r}',
 '𝖘': '\\mathslbb{s}',
 '𝖙': '\\mathslbb{t}',
 '𝖚': '\\mathslbb{u}',
 '𝖛': '\\mathslbb{v}',
 '𝖜': '\\mathslbb{w}',
 '𝖝': '\\mathslbb{x}',
 '𝖞': '\\mathslbb{y}',
 '𝖟': '\\mathslbb{z}',
 '𝖠': '\\mathsf{A}',
 '𝖡': '\\mathsf{B}',
 '𝖢': '\\mathsf{C}',
 '𝖣': '\\mathsf{D}',
 '𝖤': '\\mathsf{E}',
 '𝖥': '\\mathsf{F}',
 '𝖦': '\\mathsf{G}',
 '𝖧': '\\mathsf{H}',
 '𝖨': '\\mathsf{I}',
 '𝖩': '\\mathsf{J}',
 '𝖪': '\\mathsf{K}',
 '𝖫': '\\mathsf{L}',
 '𝖬': '\\mathsf{M}',
 '𝖭': '\\mathsf{N}',
 '𝖮': '\\mathsf{O}',
 '𝖯': '\\mathsf{P}',
 '𝖰': '\\mathsf{Q}',
 '𝖱': '\\mathsf{R}',
 '𝖲': '\\mathsf{S}',
 '𝖳': '\\mathsf{T}',
 '𝖴': '\\mathsf{U}',
 '𝖵': '\\mathsf{V}',
 '𝖶': '\\mathsf{W}',
 '𝖷': '\\mathsf{X}',
 '𝖸': '\\mathsf{Y}',
 '𝖹': '\\mathsf{Z}',
 '𝖺': '\\mathsf{a}',
 '𝖻': '\\mathsf{b}',
 '𝖼': '\\mathsf{c}',
 '𝖽': '\\mathsf{d}',
 '𝖾': '\\mathsf{e}',
 '𝖿': '\\mathsf{f}',
 '𝗀': '\\mathsf{g}',
 '𝗁': '\\mathsf{h}',
 '𝗂': '\\mathsf{i}',
 '𝗃': '\\mathsf{j}',
 '𝗄': '\\mathsf{k}',
 '𝗅': '\\mathsf{l}',
 '𝗆': '\\mathsf{m}',
 '𝗇': '\\mathsf{n}',
 '𝗈': '\\mathsf{o}',
 '𝗉': '\\mathsf{p}',
 '𝗊': '\\mathsf{q}',
 '𝗋': '\\mathsf{r}',
 '𝗌': '\\mathsf{s}',
 '𝗍': '\\mathsf{t}',
 '𝗎': '\\mathsf{u}',
 '𝗏': '\\mathsf{v}',
 '𝗐': '\\mathsf{w}',
 '𝗑': '\\mathsf{x}',
 '𝗒': '\\mathsf{y}',
 '𝗓': '\\mathsf{z}',
 '𝗔': '\\mathsfbf{A}',
 '𝗕': '\\mathsfbf{B}',
 '𝗖': '\\mathsfbf{C}',
 '𝗗': '\\mathsfbf{D}',
 '𝗘': '\\mathsfbf{E}',
 '𝗙': '\\mathsfbf{F}',
 '𝗚': '\\mathsfbf{G}',
 '𝗛': '\\mathsfbf{H}',
 '𝗜': '\\mathsfbf{I}',
 '𝗝': '\\mathsfbf{J}',
 '𝗞': '\\mathsfbf{K}',
 '𝗟': '\\mathsfbf{L}',
 '𝗠': '\\mathsfbf{M}',
 '𝗡': '\\mathsfbf{N}',
 '𝗢': '\\mathsfbf{O}',
 '𝗣': '\\mathsfbf{P}',
 '𝗤': '\\mathsfbf{Q}',
 '𝗥': '\\mathsfbf{R}',
 '𝗦': '\\mathsfbf{S}',
 '𝗧': '\\mathsfbf{T}',
 '𝗨': '\\mathsfbf{U}',
 '𝗩': '\\mathsfbf{V}',
 '𝗪': '\\mathsfbf{W}',
 '𝗫': '\\mathsfbf{X}',
 '𝗬': '\\mathsfbf{Y}',
 '𝗭': '\\mathsfbf{Z}',
 '𝗮': '\\mathsfbf{a}',
 '𝗯': '\\mathsfbf{b}',
 '𝗰': '\\mathsfbf{c}',
 '𝗱': '\\mathsfbf{d}',
 '𝗲': '\\mathsfbf{e}',
 '𝗳': '\\mathsfbf{f}',
 '𝗴': '\\mathsfbf{g}',
 '𝗵': '\\mathsfbf{h}',
 '𝗶': '\\mathsfbf{i}',
 '𝗷': '\\mathsfbf{j}',
 '𝗸': '\\mathsfbf{k}',
 '𝗹': '\\mathsfbf{l}',
 '𝗺': '\\mathsfbf{m}',
 '𝗻': '\\mathsfbf{n}',
 '𝗼': '\\mathsfbf{o}',
 '𝗽': '\\mathsfbf{p}',
 '𝗾': '\\mathsfbf{q}',
 '𝗿': '\\mathsfbf{r}',
 '𝘀': '\\mathsfbf{s}',
 '𝘁': '\\mathsfbf{t}',
 '𝘂': '\\mathsfbf{u}',
 '𝘃': '\\mathsfbf{v}',
 '𝘄': '\\mathsfbf{w}',
 '𝘅': '\\mathsfbf{x}',
 '𝘆': '\\mathsfbf{y}',
 '𝘇': '\\mathsfbf{z}',
 '𝘈': '\\mathsfsl{A}',
 '𝘉': '\\mathsfsl{B}',
 '𝘊': '\\mathsfsl{C}',
 '𝘋': '\\mathsfsl{D}',
 '𝘌': '\\mathsfsl{E}',
 '𝘍': '\\mathsfsl{F}',
 '𝘎': '\\mathsfsl{G}',
 '𝘏': '\\mathsfsl{H}',
 '𝘐': '\\mathsfsl{I}',
 '𝘑': '\\mathsfsl{J}',
 '𝘒': '\\mathsfsl{K}',
 '𝘓': '\\mathsfsl{L}',
 '𝘔': '\\mathsfsl{M}',
 '𝘕': '\\mathsfsl{N}',
 '𝘖': '\\mathsfsl{O}',
 '𝘗': '\\mathsfsl{P}',
 '𝘘': '\\mathsfsl{Q}',
 '𝘙': '\\mathsfsl{R}',
 '𝘚': '\\mathsfsl{S}',
 '𝘛': '\\mathsfsl{T}',
 '𝘜': '\\mathsfsl{U}',
 '𝘝': '\\mathsfsl{V}',
 '𝘞': '\\mathsfsl{W}',
 '𝘟': '\\mathsfsl{X}',
 '𝘠': '\\mathsfsl{Y}',
 '𝘡': '\\mathsfsl{Z}',
 '𝘢': '\\mathsfsl{a}',
 '𝘣': '\\mathsfsl{b}',
 '𝘤': '\\mathsfsl{c}',
 '𝘥': '\\mathsfsl{d}',
 '𝘦': '\\mathsfsl{e}',
 '𝘧': '\\mathsfsl{f}',
 '𝘨': '\\mathsfsl{g}',
 '𝘩': '\\mathsfsl{h}',
 '𝘪': '\\mathsfsl{i}',
 '𝘫': '\\mathsfsl{j}',
 '𝘬': '\\mathsfsl{k}',
 '𝘭': '\\mathsfsl{l}',
 '𝘮': '\\mathsfsl{m}',
 '𝘯': '\\mathsfsl{n}',
 '𝘰': '\\mathsfsl{o}',
 '𝘱': '\\mathsfsl{p}',
 '𝘲': '\\mathsfsl{q}',
 '𝘳': '\\mathsfsl{r}',
 '𝘴': '\\mathsfsl{s}',
 '𝘵': '\\mathsfsl{t}',
 '𝘶': '\\mathsfsl{u}',
 '𝘷': '\\mathsfsl{v}',
 '𝘸': '\\mathsfsl{w}',
 '𝘹': '\\mathsfsl{x}',
 '𝘺': '\\mathsfsl{y}',
 '𝘻': '\\mathsfsl{z}',
 '𝘼': '\\mathsfbfsl{A}',
 '𝘽': '\\mathsfbfsl{B}',
 '𝘾': '\\mathsfbfsl{C}',
 '𝘿': '\\mathsfbfsl{D}',
 '𝙀': '\\mathsfbfsl{E}',
 '𝙁': '\\mathsfbfsl{F}',
 '𝙂': '\\mathsfbfsl{G}',
 '𝙃': '\\mathsfbfsl{H}',
 '𝙄': '\\mathsfbfsl{I}',
 '𝙅': '\\mathsfbfsl{J}',
 '𝙆': '\\mathsfbfsl{K}',
 '𝙇': '\\mathsfbfsl{L}',
 '𝙈': '\\mathsfbfsl{M}',
 '𝙉': '\\mathsfbfsl{N}',
 '𝙊': '\\mathsfbfsl{O}',
 '𝙋': '\\mathsfbfsl{P}',
 '𝙌': '\\mathsfbfsl{Q}',
 '𝙍': '\\mathsfbfsl{R}',
 '𝙎': '\\mathsfbfsl{S}',
 '𝙏': '\\mathsfbfsl{T}',
 '𝙐': '\\mathsfbfsl{U}',
 '𝙑': '\\mathsfbfsl{V}',
 '𝙒': '\\mathsfbfsl{W}',
 '𝙓': '\\mathsfbfsl{X}',
 '𝙔': '\\mathsfbfsl{Y}',
 '𝙕': '\\mathsfbfsl{Z}',
 '𝙖': '\\mathsfbfsl{a}',
 '𝙗': '\\mathsfbfsl{b}',
 '𝙘': '\\mathsfbfsl{c}',
 '𝙙': '\\mathsfbfsl{d}',
 '𝙚': '\\mathsfbfsl{e}',
 '𝙛': '\\mathsfbfsl{f}',
 '𝙜': '\\mathsfbfsl{g}',
 '𝙝': '\\mathsfbfsl{h}',
 '𝙞': '\\mathsfbfsl{i}',
 '𝙟': '\\mathsfbfsl{j}',
 '𝙠': '\\mathsfbfsl{k}',
 '𝙡': '\\mathsfbfsl{l}',
 '𝙢': '\\mathsfbfsl{m}',
 '𝙣': '\\mathsfbfsl{n}',
 '𝙤': '\\mathsfbfsl{o}',
 '𝙥': '\\mathsfbfsl{p}',
 '𝙦': '\\mathsfbfsl{q}',
 '𝙧': '\\mathsfbfsl{r}',
 '𝙨': '\\mathsfbfsl{s}',
 '𝙩': '\\mathsfbfsl{t}',
 '𝙪': '\\mathsfbfsl{u}',
 '𝙫': '\\mathsfbfsl{v}',
 '𝙬': '\\mathsfbfsl{w}',
 '𝙭': '\\mathsfbfsl{x}',
 '𝙮': '\\mathsfbfsl{y}',
 '𝙯': '\\mathsfbfsl{z}',
 '𝙰': '\\mathtt{A}',
 '𝙱': '\\mathtt{B}',
 '𝙲': '\\mathtt{C}',
 '𝙳': '\\mathtt{D}',
 '𝙴': '\\mathtt{E}',
 '𝙵': '\\mathtt{F}',
 '𝙶': '\\mathtt{G}',
 '𝙷': '\\mathtt{H}',
 '𝙸': '\\mathtt{I}',
 '𝙹': '\\mathtt{J}',
 '𝙺': '\\mathtt{K}',
 '𝙻': '\\mathtt{L}',
 '𝙼': '\\mathtt{M}',
 '𝙽': '\\mathtt{N}',
 '𝙾': '\\mathtt{O}',
 '𝙿': '\\mathtt{P}',
 '𝚀': '\\mathtt{Q}',
 '𝚁': '\\mathtt{R}',
 '𝚂': '\\mathtt{S}',
 '𝚃': '\\mathtt{T}',
 '𝚄': '\\mathtt{U}',
 '𝚅': '\\mathtt{V}',
 '𝚆': '\\mathtt{W}',
 '𝚇': '\\mathtt{X}',
 '𝚈': '\\mathtt{Y}',
 '𝚉': '\\mathtt{Z}',
 '𝚊': '\\mathtt{a}',
 '𝚋': '\\mathtt{b}',
 '𝚌': '\\mathtt{c}',
 '𝚍': '\\mathtt{d}',
 '𝚎': '\\mathtt{e}',
 '𝚏': '\\mathtt{f}',
 '𝚐': '\\mathtt{g}',
 '𝚑': '\\mathtt{h}',
 '𝚒': '\\mathtt{i}',
 '𝚓': '\\mathtt{j}',
 '𝚔': '\\mathtt{k}',
 '𝚕': '\\mathtt{l}',
 '𝚖': '\\mathtt{m}',
 '𝚗': '\\mathtt{n}',
 '𝚘': '\\mathtt{o}',
 '𝚙': '\\mathtt{p}',
 '𝚚': '\\mathtt{q}',
 '𝚛': '\\mathtt{r}',
 '𝚜': '\\mathtt{s}',
 '𝚝': '\\mathtt{t}',
 '𝚞': '\\mathtt{u}',
 '𝚟': '\\mathtt{v}',
 '𝚠': '\\mathtt{w}',
 '𝚡': '\\mathtt{x}',
 '𝚢': '\\mathtt{y}',
 '𝚣': '\\mathtt{z}',
 '𝚨': '\\mathbf{\\Alpha}',
 '𝚩': '\\mathbf{\\Beta}',
 '𝚪': '\\mathbf{\\Gamma}',
 '𝚫': '\\mathbf{\\Delta}',
 '𝚬': '\\mathbf{\\Epsilon}',
 '𝚭': '\\mathbf{\\Zeta}',
 '𝚮': '\\mathbf{\\Eta}',
 '𝚯': '\\mathbf{\\Theta}',
 '𝚰': '\\mathbf{\\Iota}',
 '𝚱': '\\mathbf{\\Kappa}',
 '𝚲': '\\mathbf{\\Lambda}',
 '𝚳': 'M',
 '𝚴': 'N',
 '𝚵': '\\mathbf{\\Xi}',
 '𝚶': 'O',
 '𝚷': '\\mathbf{\\Pi}',
 '𝚸': '\\mathbf{\\Rho}',
 '𝚹': '\\mathbf{\\vartheta}',
 '𝚺': '\\mathbf{\\Sigma}',
 '𝚻': '\\mathbf{\\Tau}',
 '𝚼': '\\mathbf{\\Upsilon}',
 '𝚽': '\\mathbf{\\Phi}',
 '𝚾': '\\mathbf{\\Chi}',
 '𝚿': '\\mathbf{\\Psi}',
 '𝛀': '\\mathbf{\\Omega}',
 '𝛁': '\\mathbf{\\nabla}',
 '𝛂': '\\mathbf{\\Alpha}',
 '𝛃': '\\mathbf{\\Beta}',
 '𝛄': '\\mathbf{\\Gamma}',
 '𝛅': '\\mathbf{\\Delta}',
 '𝛆': '\\mathbf{\\Epsilon}',
 '𝛇': '\\mathbf{\\Zeta}',
 '𝛈': '\\mathbf{\\Eta}',
 '𝛉': '\\mathbf{\\theta}',
 '𝛊': '\\mathbf{\\Iota}',
 '𝛋': '\\mathbf{\\Kappa}',
 '𝛌': '\\mathbf{\\Lambda}',
 '𝛍': 'M',
 '𝛎': 'N',
 '𝛏': '\\mathbf{\\Xi}',
 '𝛐': 'O',
 '𝛑': '\\mathbf{\\Pi}',
 '𝛒': '\\mathbf{\\Rho}',
 '𝛓': '\\mathbf{\\varsigma}',
 '𝛔': '\\mathbf{\\Sigma}',
 '𝛕': '\\mathbf{\\Tau}',
 '𝛖': '\\mathbf{\\Upsilon}',
 '𝛗': '\\mathbf{\\Phi}',
 '𝛘': '\\mathbf{\\Chi}',
 '𝛙': '\\mathbf{\\Psi}',
 '𝛚': '\\mathbf{\\Omega}',
 '𝛛': '{\\partial}',
 '𝛜': '{\\in}',
 '𝛝': '\\mathbf{\\vartheta}',
 '𝛞': '\\mathbf{\\varkappa}',
 '𝛟': '\\mathbf{\\phi}',
 '𝛠': '\\mathbf{\\varrho}',
 '𝛡': '\\mathbf{\\varpi}',
 '𝛢': '\\mathsl{\\Alpha}',
 '𝛣': '\\mathsl{\\Beta}',
 '𝛤': '\\mathsl{\\Gamma}',
 '𝛥': '\\mathsl{\\Delta}',
 '𝛦': '\\mathsl{\\Epsilon}',
 '𝛧': '\\mathsl{\\Zeta}',
 '𝛨': '\\mathsl{\\Eta}',
 '𝛩': '\\mathsl{\\Theta}',
 '𝛪': '\\mathsl{\\Iota}',
 '𝛫': '\\mathsl{\\Kappa}',
 '𝛬': '\\mathsl{\\Lambda}',
 '𝛭': 'M',
 '𝛮': 'N',
 '𝛯': '\\mathsl{\\Xi}',
 '𝛰': 'O',
 '𝛱': '\\mathsl{\\Pi}',
 '𝛲': '\\mathsl{\\Rho}',
 '𝛳': '\\mathsl{\\vartheta}',
 '𝛴': '\\mathsl{\\Sigma}',
 '𝛵': '\\mathsl{\\Tau}',
 '𝛶': '\\mathsl{\\Upsilon}',
 '𝛷': '\\mathsl{\\Phi}',
 '𝛸': '\\mathsl{\\Chi}',
 '𝛹': '\\mathsl{\\Psi}',
 '𝛺': '\\mathsl{\\Omega}',
 '𝛻': '\\mathsl{\\nabla}',
 '𝛼': '\\mathsl{\\Alpha}',
 '𝛽': '\\mathsl{\\Beta}',
 '𝛾': '\\mathsl{\\Gamma}',
 '𝛿': '\\mathsl{\\Delta}',
 '𝜀': '\\mathsl{\\Epsilon}',
 '𝜁': '\\mathsl{\\Zeta}',
 '𝜂': '\\mathsl{\\Eta}',
 '𝜃': '\\mathsl{\\Theta}',
 '𝜄': '\\mathsl{\\Iota}',
 '𝜅': '\\mathsl{\\Kappa}',
 '𝜆': '\\mathsl{\\Lambda}',
 '𝜇': 'M',
 '𝜈': 'N',
 '𝜉': '\\mathsl{\\Xi}',
 '𝜊': 'O',
 '𝜋': '\\mathsl{\\Pi}',
 '𝜌': '\\mathsl{\\Rho}',
 '𝜍': '\\mathsl{\\varsigma}',
 '𝜎': '\\mathsl{\\Sigma}',
 '𝜏': '\\mathsl{\\Tau}',
 '𝜐': '\\mathsl{\\Upsilon}',
 '𝜑': '\\mathsl{\\Phi}',
 '𝜒': '\\mathsl{\\Chi}',
 '𝜓': '\\mathsl{\\Psi}',
 '𝜔': '\\mathsl{\\Omega}',
 '𝜕': '{\\partial}',
 '𝜖': '{\\in}',
 '𝜗': '\\mathsl{\\vartheta}',
 '𝜘': '\\mathsl{\\varkappa}',
 '𝜙': '\\mathsl{\\phi}',
 '𝜚': '\\mathsl{\\varrho}',
 '𝜛': '\\mathsl{\\varpi}',
 '𝜜': '\\mathbit{\\Alpha}',
 '𝜝': '\\mathbit{\\Beta}',
 '𝜞': '\\mathbit{\\Gamma}',
 '𝜟': '\\mathbit{\\Delta}',
 '𝜠': '\\mathbit{\\Epsilon}',
 '𝜡': '\\mathbit{\\Zeta}',
 '𝜢': '\\mathbit{\\Eta}',
 '𝜣': '\\mathbit{\\Theta}',
 '𝜤': '\\mathbit{\\Iota}',
 '𝜥': '\\mathbit{\\Kappa}',
 '𝜦': '\\mathbit{\\Lambda}',
 '𝜧': 'M',
 '𝜨': 'N',
 '𝜩': '\\mathbit{\\Xi}',
 '𝜪': 'O',
 '𝜫': '\\mathbit{\\Pi}',
 '𝜬': '\\mathbit{\\Rho}',
 '𝜭': '\\mathbit{O}',
 '𝜮': '\\mathbit{\\Sigma}',
 '𝜯': '\\mathbit{\\Tau}',
 '𝜰': '\\mathbit{\\Upsilon}',
 '𝜱': '\\mathbit{\\Phi}',
 '𝜲': '\\mathbit{\\Chi}',
 '𝜳': '\\mathbit{\\Psi}',
 '𝜴': '\\mathbit{\\Omega}',
 '𝜵': '\\mathbit{\\nabla}',
 '𝜶': '\\mathbit{\\Alpha}',
 '𝜷': '\\mathbit{\\Beta}',
 '𝜸': '\\mathbit{\\Gamma}',
 '𝜹': '\\mathbit{\\Delta}',
 '𝜺': '\\mathbit{\\Epsilon}',
 '𝜻': '\\mathbit{\\Zeta}',
 '𝜼': '\\mathbit{\\Eta}',
 '𝜽': '\\mathbit{\\Theta}',
 '𝜾': '\\mathbit{\\Iota}',
 '𝜿': '\\mathbit{\\Kappa}',
 '𝝀': '\\mathbit{\\Lambda}',
 '𝝁': 'M',
 '𝝂': 'N',
 '𝝃': '\\mathbit{\\Xi}',
 '𝝄': 'O',
 '𝝅': '\\mathbit{\\Pi}',
 '𝝆': '\\mathbit{\\Rho}',
 '𝝇': '\\mathbit{\\varsigma}',
 '𝝈': '\\mathbit{\\Sigma}',
 '𝝉': '\\mathbit{\\Tau}',
 '𝝊': '\\mathbit{\\Upsilon}',
 '𝝋': '\\mathbit{\\Phi}',
 '𝝌': '\\mathbit{\\Chi}',
 '𝝍': '\\mathbit{\\Psi}',
 '𝝎': '\\mathbit{\\Omega}',
 '𝝏': '{\\partial}',
 '𝝐': '{\\in}',
 '𝝑': '\\mathbit{\\vartheta}',
 '𝝒': '\\mathbit{\\varkappa}',
 '𝝓': '\\mathbit{\\phi}',
 '𝝔': '\\mathbit{\\varrho}',
 '𝝕': '\\mathbit{\\varpi}',
 '𝝖': '\\mathsfbf{\\Alpha}',
 '𝝗': '\\mathsfbf{\\Beta}',
 '𝝘': '\\mathsfbf{\\Gamma}',
 '𝝙': '\\mathsfbf{\\Delta}',
 '𝝚': '\\mathsfbf{\\Epsilon}',
 '𝝛': '\\mathsfbf{\\Zeta}',
 '𝝜': '\\mathsfbf{\\Eta}',
 '𝝝': '\\mathsfbf{\\Theta}',
 '𝝞': '\\mathsfbf{\\Iota}',
 '𝝟': '\\mathsfbf{\\Kappa}',
 '𝝠': '\\mathsfbf{\\Lambda}',
 '𝝡': 'M',
 '𝝢': 'N',
 '𝝣': '\\mathsfbf{\\Xi}',
 '𝝤': 'O',
 '𝝥': '\\mathsfbf{\\Pi}',
 '𝝦': '\\mathsfbf{\\Rho}',
 '𝝧': '\\mathsfbf{\\vartheta}',
 '𝝨': '\\mathsfbf{\\Sigma}',
 '𝝩': '\\mathsfbf{\\Tau}',
 '𝝪': '\\mathsfbf{\\Upsilon}',
 '𝝫': '\\mathsfbf{\\Phi}',
 '𝝬': '\\mathsfbf{\\Chi}',
 '𝝭': '\\mathsfbf{\\Psi}',
 '𝝮': '\\mathsfbf{\\Omega}',
 '𝝯': '\\mathsfbf{\\nabla}',
 '𝝰': '\\mathsfbf{\\Alpha}',
 '𝝱': '\\mathsfbf{\\Beta}',
 '𝝲': '\\mathsfbf{\\Gamma}',
 '𝝳': '\\mathsfbf{\\Delta}',
 '𝝴': '\\mathsfbf{\\Epsilon}',
 '𝝵': '\\mathsfbf{\\Zeta}',
 '𝝶': '\\mathsfbf{\\Eta}',
 '𝝷': '\\mathsfbf{\\Theta}',
 '𝝸': '\\mathsfbf{\\Iota}',
 '𝝹': '\\mathsfbf{\\Kappa}',
 '𝝺': '\\mathsfbf{\\Lambda}',
 '𝝻': 'M',
 '𝝼': 'N',
 '𝝽': '\\mathsfbf{\\Xi}',
 '𝝾': 'O',
 '𝝿': '\\mathsfbf{\\Pi}',
 '𝞀': '\\mathsfbf{\\Rho}',
 '𝞁': '\\mathsfbf{\\varsigma}',
 '𝞂': '\\mathsfbf{\\Sigma}',
 '𝞃': '\\mathsfbf{\\Tau}',
 '𝞄': '\\mathsfbf{\\Upsilon}',
 '𝞅': '\\mathsfbf{\\Phi}',
 '𝞆': '\\mathsfbf{\\Chi}',
 '𝞇': '\\mathsfbf{\\Psi}',
 '𝞈': '\\mathsfbf{\\Omega}',
 '𝞉': '{\\partial}',
 '𝞊': '{\\in}',
 '𝞋': '\\mathsfbf{\\vartheta}',
 '𝞌': '\\mathsfbf{\\varkappa}',
 '𝞍': '\\mathsfbf{\\phi}',
 '𝞎': '\\mathsfbf{\\varrho}',
 '𝞏': '\\mathsfbf{\\varpi}',
 '𝞐': '\\mathsfbfsl{\\Alpha}',
 '𝞑': '\\mathsfbfsl{\\Beta}',
 '𝞒': '\\mathsfbfsl{\\Gamma}',
 '𝞓': '\\mathsfbfsl{\\Delta}',
 '𝞔': '\\mathsfbfsl{\\Epsilon}',
 '𝞕': '\\mathsfbfsl{\\Zeta}',
 '𝞖': '\\mathsfbfsl{\\Eta}',
 '𝞗': '\\mathsfbfsl{\\vartheta}',
 '𝞘': '\\mathsfbfsl{\\Iota}',
 '𝞙': '\\mathsfbfsl{\\Kappa}',
 '𝞚': '\\mathsfbfsl{\\Lambda}',
 '𝞛': 'M',
 '𝞜': 'N',
 '𝞝': '\\mathsfbfsl{\\Xi}',
 '𝞞': 'O',
 '𝞟': '\\mathsfbfsl{\\Pi}',
 '𝞠': '\\mathsfbfsl{\\Rho}',
 '𝞡': '\\mathsfbfsl{\\vartheta}',
 '𝞢': '\\mathsfbfsl{\\Sigma}',
 '𝞣': '\\mathsfbfsl{\\Tau}',
 '𝞤': '\\mathsfbfsl{\\Upsilon}',
 '𝞥': '\\mathsfbfsl{\\Phi}',
 '𝞦': '\\mathsfbfsl{\\Chi}',
 '𝞧': '\\mathsfbfsl{\\Psi}',
 '𝞨': '\\mathsfbfsl{\\Omega}',
 '𝞩': '\\mathsfbfsl{\\nabla}',
 '𝞪': '\\mathsfbfsl{\\Alpha}',
 '𝞫': '\\mathsfbfsl{\\Beta}',
 '𝞬': '\\mathsfbfsl{\\Gamma}',
 '𝞭': '\\mathsfbfsl{\\Delta}',
 '𝞮': '\\mathsfbfsl{\\Epsilon}',
 '𝞯': '\\mathsfbfsl{\\Zeta}',
 '𝞰': '\\mathsfbfsl{\\Eta}',
 '𝞱': '\\mathsfbfsl{\\vartheta}',
 '𝞲': '\\mathsfbfsl{\\Iota}',
 '𝞳': '\\mathsfbfsl{\\Kappa}',
 '𝞴': '\\mathsfbfsl{\\Lambda}',
 '𝞵': 'M',
 '𝞶': 'N',
 '𝞷': '\\mathsfbfsl{\\Xi}',
 '𝞸': 'O',
 '𝞹': '\\mathsfbfsl{\\Pi}',
 '𝞺': '\\mathsfbfsl{\\Rho}',
 '𝞻': '\\mathsfbfsl{\\varsigma}',
 '𝞼': '\\mathsfbfsl{\\Sigma}',
 '𝞽': '\\mathsfbfsl{\\Tau}',
 '𝞾': '\\mathsfbfsl{\\Upsilon}',
 '𝞿': '\\mathsfbfsl{\\Phi}',
 '𝟀': '\\mathsfbfsl{\\Chi}',
 '𝟁': '\\mathsfbfsl{\\Psi}',
 '𝟂': '\\mathsfbfsl{\\Omega}',
 '𝟃': '{\\partial}',
 '𝟄': '{\\in}',
 '𝟅': '\\mathsfbfsl{\\vartheta}',
 '𝟆': '\\mathsfbfsl{\\varkappa}',
 '𝟇': '\\mathsfbfsl{\\phi}',
 '𝟈': '\\mathsfbfsl{\\varrho}',
 '𝟉': '\\mathsfbfsl{\\varpi}',
 '𝟎': '\\mathbf{0}',
 '𝟏': '\\mathbf{1}',
 '𝟐': '\\mathbf{2}',
 '𝟑': '\\mathbf{3}',
 '𝟒': '\\mathbf{4}',
 '𝟓': '\\mathbf{5}',
 '𝟔': '\\mathbf{6}',
 '𝟕': '\\mathbf{7}',
 '𝟖': '\\mathbf{8}',
 '𝟗': '\\mathbf{9}',
 '𝟘': '\\mathbb{0}',
 '𝟙': '\\mathbb{1}',
 '𝟚': '\\mathbb{2}',
 '𝟛': '\\mathbb{3}',
 '𝟜': '\\mathbb{4}',
 '𝟝': '\\mathbb{5}',
 '𝟞': '\\mathbb{6}',
 '𝟟': '\\mathbb{7}',
 '𝟠': '\\mathbb{8}',
 '𝟡': '\\mathbb{9}',
 '𝟢': '\\mathsf{0}',
 '𝟣': '\\mathsf{1}',
 '𝟤': '\\mathsf{2}',
 '𝟥': '\\mathsf{3}',
 '𝟦': '\\mathsf{4}',
 '𝟧': '\\mathsf{5}',
 '𝟨': '\\mathsf{6}',
 '𝟩': '\\mathsf{7}',
 '𝟪': '\\mathsf{8}',
 '𝟫': '\\mathsf{9}',
 '𝟬': '\\mathsfbf{0}',
 '𝟭': '\\mathsfbf{1}',
 '𝟮': '\\mathsfbf{2}',
 '𝟯': '\\mathsfbf{3}',
 '𝟰': '\\mathsfbf{4}',
 '𝟱': '\\mathsfbf{5}',
 '𝟲': '\\mathsfbf{6}',
 '𝟳': '\\mathsfbf{7}',
 '𝟴': '\\mathsfbf{8}',
 '𝟵': '\\mathsfbf{9}',
 '𝟶': '\\mathtt{0}',
 '𝟷': '\\mathtt{1}',
 '𝟸': '\\mathtt{2}',
 '𝟹': '\\mathtt{3}',
 '𝟺': '\\mathtt{4}',
 '𝟻': '\\mathtt{5}',
 '𝟼': '\\mathtt{6}',
 '𝟽': '\\mathtt{7}',
 '𝟾': '\\mathtt{8}',
 '𝟿': '\\mathtt{9}'
 }
